from aiogram import types, F
from aiogram.fsm.context import FSMContext
from aiogram.fsm.state import State, StatesGroup
from aiogram.utils.keyboard import ReplyKeyboardMarkup, KeyboardButton
from datetime import datetime
import json
import os
from aiogram.types import InlineKeyboardButton, InlineKeyboardMarkup
import asyncio
from pathlib import Path
from aiogram.types import FSInputFile
from apscheduler.schedulers.asyncio import AsyncIOScheduler
import sys
from aiogram import Bot

DATA_DIR = Path("data")
DATA_DIR2 = Path("Initialdata")

USER_MEMORIES_FILE = DATA_DIR / "user_memories.json"  # فایل ذخیره لینک آگهی‌های کاربران
CHANNEL_IDM = "UniMarket_ir"  # آیدی کانال بدون @
CHANNEL_IDs = -1002556484316  # آیدی عددی کانال شما
scheduler = AsyncIOScheduler()


SUPPORT_USERNAME = "ShUAdmin"  # یوزرنیم پشتیبانی
BANNED_WORDS_FILE = DATA_DIR2 / "banned_words.json"

def load_banned_words():
    """بارگذاری لیست کلمات ممنوعه از فایل"""
    try:
        if BANNED_WORDS_FILE.exists():
            with open(BANNED_WORDS_FILE, 'r', encoding='utf-8') as f:
                return json.load(f)
        # اگر فایل وجود نداشت، یک فایل با لیست پیش‌فرض ایجاد می‌کنیم
        save_banned_words(DEFAULT_BANNED_WORDS)
        return DEFAULT_BANNED_WORDS
    except Exception as e:
        return DEFAULT_BANNED_WORDS

def save_banned_words(words_list):
    """ذخیره لیست کلمات ممنوعه در فایل"""
    try:
        DATA_DIR2.mkdir(exist_ok=True)
        with open(BANNED_WORDS_FILE, 'w', encoding='utf-8') as f:
            json.dump(words_list, f, ensure_ascii=False, indent=2)
        return True
    except Exception as e:
        return False

BOT_TEXTS_FILE = DATA_DIR2 / "bot_texts.json"
def load_bot_texts():
    """بارگذاری متن‌های ربات از فایل JSON"""

    if BOT_TEXTS_FILE.exists():
        with open(BOT_TEXTS_FILE, 'r', encoding='utf-8') as f:
            texts = json.load(f)
            # جایگزینی متغیرها در متن‌ها
            texts["support_text"] = texts["support_text"].replace("{SUPPORT_USERNAME}", SUPPORT_USERNAME)
            return texts

    return {
        "welcome_text": "متن در حال بروزرسانی...",
        "support_text": "متن در حال بروزرسانی...",
        "rules_text": "متن در حال بروزرسانی...",
        "helpadmin_text": "متن در حال بروزرسانی..."
    }
def save_bot_texts(texts):
    """ذخیره متن‌های ربات در فایل JSON"""

    DATA_DIR.mkdir(exist_ok=True)
    with open(BOT_TEXTS_FILE, 'w', encoding='utf-8') as f:
        json.dump(texts, f, ensure_ascii=False, indent=2)
    return True
    
bot_texts = load_bot_texts()  # بارگذاری متن‌ها

# لیست پیش‌فرض کلمات ممنوعه
DEFAULT_BANNED_WORDS = ["سکسی"]
# بارگذاری اولیه کلمات ممنوعه
banned_words = load_banned_words()

class AdminStates(StatesGroup):
    WAITING_FOR_BLOCK_INPUT = State()
    WAITING_FOR_BLOCK_REASON = State()  # حالت جدید برای دریافت دلیل بلاک
    WAITING_FOR_UNBLOCK_INPUT = State()
    WAITING_FOR_UNBLOCK_REASON = State()  # حالت جدید برای دریافت دلیل آنبلاک
    WAITING_FOR_TEMP_UNBLOCK_INPUT = State()
    WAITING_FOR_ADD_ADMIN_INPUT = State()
    WAITING_FOR_REMOVE_ADMIN_INPUT = State()
    CONFIRM_RESTART = State()
    WAITING_FOR_TEMP_UNBLOCK_REASON = State()  # حالت جدید برای دریافت دلیل رفع مسدودیت موقت

# حالت‌های جدید برای مدیریت فیلتر
class FilterStates(StatesGroup):
    WAITING_FOR_ADD_WORD = State()
    WAITING_FOR_REMOVE_WORD = State()

class UserManagementStates(StatesGroup):
    MAIN_MENU = State()
    SELECT_RECIPIENTS = State()
    ENTER_USER_IDS = State()
    CONFIRM_MESSAGE = State()
    WAITING_FOR_BLOCK_REASON = State()
    WAITING_FOR_UNBLOCK_REASON = State()
    WAITING_FOR_TEMP_UNBLOCK_INPUT = State()
    WAITING_FOR_TEMP_UNBLOCK_REASON = State()
    OFFICIALS_MENU = State()  # حالت جدید برای زیرمنوی پیام به مقام داران
    BLOCK_USER = State()  # حالت جدید برای بلاک کاربر
    UNBLOCK_USER = State()  # حالت جدید برای آنبلاک کاربر
    TEMP_UNBLOCK_USER = State()  # حالت جدید برای رفع مسدودیت موقت

class MessageManagementStates(StatesGroup):
    MAIN_MENU = State()
    EDIT_WELCOME = State()
    EDIT_SUPPORT = State()
    EDIT_RULES = State()
    EDIT_HELP_ADMIN = State()

async def get_user_management_keyboard():
    """ایجاد کیبورد مدیریت کاربران"""
    keyboard = ReplyKeyboardMarkup(
        keyboard=[
            [
                KeyboardButton(text="🚫 بلاک کاربر"),
                KeyboardButton(text="✅ آنبلاک کاربر")
            ],
            [
                KeyboardButton(text="📜 لیست کاربران بلاک شده"),
                KeyboardButton(text="⏳ رفع مسدودیت موقت")
            ],
            [
                KeyboardButton(text="📩 پیام به کاربران")
            ,
            
                KeyboardButton(text="👑 پیام به مقام داران")
            ],
            [
                KeyboardButton(text="🔙 بازگشت به منوی اصلی")
            ]
        ],
        resize_keyboard=True
    )
    return keyboard

class AdminManagementStates(StatesGroup):
    MAIN_MENU = State()
    ADD_ADMIN = State()
    REMOVE_ADMIN = State()
    SEND_ADMIN_MESSAGE = State()

async def get_admin_management_keyboard():
    """کیبورد مدیریت ادمین‌ها"""
    return ReplyKeyboardMarkup(
        keyboard=[
            [KeyboardButton(text="➖ عزل ادمین"), KeyboardButton(text="➕ افزودن ادمین")],
            [KeyboardButton(text="👥 لیست ادمین‌ها")],
            [KeyboardButton(text="🔙 بازگشت به منوی اصلی")]
        ],
        resize_keyboard=True
    )

class ContentManagementStates(StatesGroup):
    MAIN_MENU = State()
    ADD_FILTER = State()
    REMOVE_FILTER = State()

async def get_content_management_keyboard():
    """کیبورد مدیریت مطالب"""
    return ReplyKeyboardMarkup(
        keyboard=[
            [KeyboardButton(text="📜 لیست کلمات فیلتر"), KeyboardButton(text="🗑️ حذف آگهی")],
            [KeyboardButton(text="➖ حذف فیلتر"), KeyboardButton(text="➕ افزودن فیلتر")],
            [KeyboardButton(text="🔙 بازگشت به منوی اصلی")]
        ],
        resize_keyboard=True
    )

async def get_message_management_keyboard():
    """کیبورد مدیریت پیام‌ها"""
    return ReplyKeyboardMarkup(
        keyboard=[
            [KeyboardButton(text="✏️ ویرایش پشتیبانی"), KeyboardButton(text="✏️ ویرایش خوشامد")],
            [KeyboardButton(text="✏️ ویرایش راهنمای ادمین"), KeyboardButton(text="✏️ ویرایش قوانین")],
            [KeyboardButton(text="🔙 بازگشت به منوی اصلی")]
        ],
        resize_keyboard=True
    )

class DeleteMemoryStates(StatesGroup):
    waiting_for_reason = State()  # حالت انتظار برای دریافت دلیل حذف

async def get_stats_keyboard():
    """کیبورد زیرمنوی آمار"""
    return ReplyKeyboardMarkup(
        keyboard=[
            [KeyboardButton(text="📤 خروجی داده‌ها"), KeyboardButton(text="📈 آمار اولیه")],
            [KeyboardButton(text="🔄 ریستارت ربات")],  # دکمه جدید
            [KeyboardButton(text="🔙 بازگشت به منوی اصلی")]
        ],
        resize_keyboard=True
    )

class DeleteMemoryStates(StatesGroup):
    waiting_for_memory_id = State()  # حالت جدید برای دریافت آیدی پیام
    waiting_for_reason = State()     # حالت برای دریافت دلیل
    
async def get_admin_keyboard():
    """کیبورد اصلی برای ادمین‌ها"""
    return ReplyKeyboardMarkup(
        keyboard=[
            [KeyboardButton(text="💠 ارسال آگهی")],
            [KeyboardButton(text="🤙 ارتباط با پشتیبانی"), KeyboardButton(text="📊 آگهی‌های من")],
            # [KeyboardButton(text="📞 ارتباط با پشتیبانی"), KeyboardButton(text="📔 آگهی‌های دیگران")],
            # [KeyboardButton(text="🏆 امتیاز من"), KeyboardButton(text="👥 دعوت دوستان")],
            [KeyboardButton(text="🔽🔽🔽 پنل مخصوص ادمین 🔽🔽🔽")],
            [KeyboardButton(text="📝 مدیریت آگهی‌ها"), KeyboardButton(text="👥 مدیریت کاربران")],
            [KeyboardButton(text="🔍 یافتن آیدی عددی"), KeyboardButton(text="👤 نمایش مشخصات من")],
            [KeyboardButton(text="🔽🔽🔽 پنل مخصوص سازنده 🔽🔽🔽")],
            [KeyboardButton(text="📩 مدیریت پیام‌ها"), KeyboardButton(text="👑 مدیریت ادمین‌ها")],
            [KeyboardButton(text="📊 اطلاعات ربات")],
        ],
        resize_keyboard=True
    )


async def get_cancel_keyboard():
    """کیبورد لغو عملیات"""
    return ReplyKeyboardMarkup(
        keyboard=[
            [KeyboardButton(text="🔙 بازگشت به منوی اصلی")]
        ],
        resize_keyboard=True
    )

async def handle_add_admin(message: types.Message, state: FSMContext):
    """شروع فرآیند افزودن ادمین"""
    try:
        await state.set_state(AdminStates.WAITING_FOR_ADD_ADMIN_INPUT)
        await message.answer(
            "لطفاً آیدی عددی کاربر را برای افزودن به لیست ادمین‌ها وارد کنید:\n\n"
            "⚠️ فقط آیدی عددی قابل قبول است\n"
            "برای یافتن آیدی عددی کاربر می‌توانید از ربات @useridinfobot استفاده کنید\n\n"
            "برای لغو عملیات از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )
    except Exception as e:
        await message.answer(
            f"خطا در شروع فرآیند افزودن ادمین: {str(e)}",
            reply_markup=await get_admin_keyboard()
        )
        await state.clear()

async def handle_remove_admin(message: types.Message, state: FSMContext):
    """شروع فرآیند عزل ادمین"""
    try:
        await state.set_state(AdminStates.WAITING_FOR_REMOVE_ADMIN_INPUT)
        await message.answer(
            "لطفاً آیدی عددی ادمین را برای حذف از لیست ادمین‌ها وارد کنید:\n\n"
            "⚠️ فقط آیدی عددی قابل قبول است\n"
            "برای یافتن آیدی عددی کاربر می‌توانید از ربات @useridinfobot استفاده کنید\n\n"
            "برای لغو عملیات از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )
    except Exception as e:
        await message.answer(
            f"خطا در شروع فرآیند عزل ادمین: {str(e)}",
            reply_markup=await get_admin_keyboard()
        )
        await state.clear()

async def process_add_admin_input(message: types.Message, state: FSMContext, bot, admins, admins_data, DATA_DIR, ADMIN_ID):
    """پردازش اطلاعات ورودی برای افزودن ادمین"""
    try:
        # بررسی اگر کاربر روی بازگشت کلیک کرده
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.clear()
            await message.answer(
                "عملیات افزودن ادمین لغو شد.",
                reply_markup=await get_admin_keyboard()
            )
            return

        user_input = message.text.strip()
        
        # بررسی اینکه ورودی فقط عدد باشد
        if not user_input.isdigit():
            await message.answer(
                "❌ فرمت آیدی نامعتبر!\n"
                "لطفاً فقط آیدی عددی کاربر را وارد کنید.\n\n"
                "برای یافتن آیدی عددی کاربر می‌توانید از ربات @useridinfobot استفاده کنید.",
                reply_markup=await get_cancel_keyboard()
            )
            return

        user_id = int(user_input)
        
        # اعتبارسنجی آیدی کاربر
        is_valid, user = await validate_user_id(bot, user_id)
        if not is_valid:
            await message.answer(
                f"❌ کاربر با آیدی {user_id} یافت نشد!\n"
                "لطفاً آیدی عددی معتبر وارد کنید.",
                reply_markup=await get_cancel_keyboard()
            )
            return
        
        username = user.username or "ندارد"
        full_name = f"{user.first_name or ''} {user.last_name or ''}".strip()
        
        # بررسی اینکه کاربر از قبل ادمین نباشد
        if user_id in admins:
            await message.answer(
                f"ℹ️ کاربر با آیدی {user_id} از قبل ادمین است.",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        
        # افزودن کاربر به لیست ادمین‌ها
        admins.add(user_id)
        
        # به روزرسانی اطلاعات ادمین‌ها
        admins_data[str(user_id)] = {
            'first_name': user.first_name,
            'last_name': user.last_name,
            'username': user.username,
            'date': datetime.now().isoformat(),
            'added_by': message.from_user.id
        }
        
        # ذخیره لیست ادمین‌ها
        try:
            with open(os.path.join(DATA_DIR, "admins.json"), 'w', encoding='utf-8') as f:
                json.dump({'admins': list(admins)}, f, ensure_ascii=False, indent=2)
            
            with open(os.path.join(DATA_DIR, "admins_data.json"), 'w', encoding='utf-8') as f:
                json.dump(admins_data, f, ensure_ascii=False, indent=2)
        except Exception as e:
            await message.answer(
                f"❌ خطا در ذخیره تغییرات: {str(e)}\n\n"
                "کاربر به لیست ادمین‌ها اضافه شد اما تغییرات ذخیره نشد!",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        await state.set_state(AdminManagementStates.MAIN_MENU)
        # اطلاع به ادمین
        await message.answer(
            f"✅ کاربر زیر با موفقیت به لیست ادمین‌ها اضافه شد:\n\n"
            f"🆔 آیدی: {user_id}\n"
            f"👤 نام: {full_name}\n"
            f"📌 یوزرنیم: @{username}\n\n"
            f"تعداد ادمین‌ها: {len(admins)}",
            reply_markup=await get_admin_keyboard()
        )
        
        # ذخیره لیست ادمین‌ها
        try:
            with open(os.path.join(DATA_DIR, "admins.json"), 'w', encoding='utf-8') as f:
                json.dump({'admins': list(admins)}, f, ensure_ascii=False, indent=2)
            
            with open(os.path.join(DATA_DIR, "admins_data.json"), 'w', encoding='utf-8') as f:
                json.dump(admins_data, f, ensure_ascii=False, indent=2)
            
            # بارگذاری مجدد لیست ادمین‌ها از فایل
            with open(os.path.join(DATA_DIR, "admins.json"), 'r', encoding='utf-8') as f:
                admins.clear()
                admins.update(set(json.load(f).get('admins', [])))
                
        except Exception as e:
            await message.answer(
                f"❌ خطا در ذخیره تغییرات: {str(e)}\n\n"
                "کاربر به لیست ادمین‌ها اضافه شد اما تغییرات ذخیره نشد!",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return

        # اطلاع به کاربر جدید
        try:
            await bot.send_message(
                user_id,
                f"🎉 شما توسط سازنده به لیست ادمین‌های ربات اضافه شدید.\n\n"
                f"🍀اکنون می‌توانید از پنل مدیریت ربات استفاده کنید.🍀\n\n"
                f"🍀برای شروع دستور /start را ارسال کنید.🍀"
            )
        except Exception as e:
            await message.answer(
                f"⚠️ نتوانستم به کاربر جدید پیام افزودن به ادمین‌ها را ارسال کنم. خطا: {str(e)}",
                reply_markup=await get_admin_keyboard()
            )
        
    except Exception as e:
        await message.answer(
            f"⚠️ خطا در پردازش درخواست: {str(e)}\n\n"
            "لطفاً مجدداً تلاش کنید.",
            reply_markup=await get_admin_keyboard()
        )
    finally:
        await state.clear()

async def process_remove_admin_input(message: types.Message, state: FSMContext, bot, admins, admins_data, DATA_DIR, ADMIN_ID):
    """پردازش اطلاعات ورودی برای عزل ادمین"""
    try:
        # بررسی اگر کاربر روی بازگشت کلیک کرده
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.clear()
            await message.answer(
                "عملیات عزل ادمین لغو شد.",
                reply_markup=await get_admin_keyboard()
            )
            return

        user_input = message.text.strip()
        
        # بررسی اینکه ورودی فقط عدد باشد
        if not user_input.isdigit():
            await message.answer(
                "❌ فرمت آیدی نامعتبر!\n"
                "لطفاً فقط آیدی عددی کاربر را وارد کنید.\n\n"
                "برای یافتن آیدی عددی کاربر می‌توانید از ربات @useridinfobot استفاده کنید.",
                reply_markup=await get_cancel_keyboard()
            )
            return

        user_id = int(user_input)
        
        # اعتبارسنجی آیدی کاربر
        is_valid, user = await validate_user_id(bot, user_id)
        if not is_valid:
            await message.answer(
                f"❌ کاربر با آیدی {user_id} یافت نشد!\n"
                "لطفاً آیدی عددی معتبر وارد کنید.",
                reply_markup=await get_cancel_keyboard()
            )
            return
        
        username = user.username or "ندارد"
        full_name = f"{user.first_name or ''} {user.last_name or ''}".strip()
        
        # بررسی اینکه کاربر ادمین باشد
        if user_id not in admins:
            await message.answer(
                f"ℹ️ کاربر با آیدی {user_id} ادمین نیست.",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        
        # بررسی اینکه کاربر ادمین اصلی نباشد
        if user_id == ADMIN_ID:
            await message.answer(
                "❌ نمی‌توانید ادمین اصلی را عزل کنید!",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        
        # حذف کاربر از لیست ادمین‌ها
        admins.remove(user_id)
        
        # به روزرسانی اطلاعات ادمین‌ها
        if str(user_id) in admins_data:
            del admins_data[str(user_id)]
        
        # ذخیره لیست ادمین‌ها
        try:
            with open(os.path.join(DATA_DIR, "admins.json"), 'w', encoding='utf-8') as f:
                json.dump({'admins': list(admins)}, f, ensure_ascii=False, indent=2)
            
            with open(os.path.join(DATA_DIR, "admins_data.json"), 'w', encoding='utf-8') as f:
                json.dump(admins_data, f, ensure_ascii=False, indent=2)
        except Exception as e:
            await message.answer(
                f"❌ خطا در ذخیره تغییرات: {str(e)}\n\n"
                "کاربر از لیست ادمین‌ها حذف شد اما تغییرات ذخیره نشد!",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        await state.set_state(AdminManagementStates.MAIN_MENU)
        # اطلاع به ادمین
        await message.answer(
            f"✅ کاربر زیر با موفقیت از لیست ادمین‌ها حذف شد:\n\n"
            f"🆔 آیدی: {user_id}\n"
            f"👤 نام: {full_name}\n"
            f"📌 یوزرنیم: @{username}\n\n"
            f"تعداد ادمین‌ها: {len(admins)}",
            reply_markup=await get_admin_keyboard()
        )
        
        # اطلاع به کاربر عزل شده
        try:
            await bot.send_message(
                user_id,
                f"⚠️ شما توسط ادمین از لیست ادمین‌های ربات حذف شدید.\n\n"
                f"🍀دیگر به پنل مدیریت دسترسی ندارید.🍀\n\n"
                f"🍀برای ادامه دستور /start را ارسال کنید.🍀"
            )
        except Exception as e:
            await message.answer(
                f"⚠️ نتوانستم به کاربر عزل شده پیام حذف از ادمین‌ها را ارسال کنم. خطا: {str(e)}",
                reply_markup=await get_admin_keyboard()
            )
        
    except Exception as e:
        await message.answer(
            f"⚠️ خطا در پردازش درخواست: {str(e)}\n\n"
            "لطفاً مجدداً تلاش کنید.",
            reply_markup=await get_admin_keyboard()
        )
    finally:
        await state.clear()

async def show_admins_list(message: types.Message, bot, admins, admins_data):
    """نمایش لیست ادمین‌ها"""
    try:
        if not admins:
            await message.answer(
                "⭕ هیچ ادمینی در سیستم ثبت نشده است.",
                reply_markup=await get_admin_keyboard()
            )
            return

        admins_list = "📜 لیست ادمین‌های ربات:\n\n"
        counter = 1
        
        for admin_id in admins:
            try:
                # ابتدا سعی می‌کنیم اطلاعات به روز را از تلگرام بگیریم
                user = await bot.get_chat(admin_id)
                username = f"@{user.username}" if user.username else "بدون یوزرنیم"
                full_name = f"{user.first_name or ''} {user.last_name or ''}".strip()
                
                # اطلاعات اضافی از admins_data
                admin_info = admins_data.get(str(admin_id), {})
                added_by = admin_info.get('added_by', 'نامشخص')
                add_date = admin_info.get('date', 'نامشخص')
                
                # اگر بتوانیم اطلاعات ادمین اضافه کننده را بگیریم
                try:
                    added_by_user = await bot.get_chat(added_by)
                    added_by_name = f"@{added_by_user.username}" if added_by_user.username else f"{added_by_user.first_name or ''} {added_by_user.last_name or ''}".strip()
                except:
                    added_by_name = str(added_by)
                
                admins_list += (
                    f"{counter}. 👤 {full_name}\n"
                    f"   🆔 آیدی: {admin_id}\n"
                    f"   📌 یوزرنیم: {username}\n"
                    f"   📅 تاریخ اضافه شدن: {add_date}\n"
                    f"   ➕ اضافه شده توسط: {added_by_name}\n"
                    f"   --------------------------\n"
                )
                counter += 1
            except Exception as e:
                # اگر نتوانستیم اطلاعات به روز را بگیریم، از داده‌های ذخیره شده استفاده می‌کنیم
                admin_info = admins_data.get(str(admin_id), {})
                username = f"@{admin_info.get('username')}" if admin_info.get('username') else "بدون یوزرنیم"
                full_name = f"{admin_info.get('first_name', '')} {admin_info.get('last_name', '')}".strip()
                added_by = admin_info.get('added_by', 'نامشخص')
                add_date = admin_info.get('date', 'نامشخص')
                
                admins_list += (
                    f"{counter}. 👤 {full_name or 'نامشخص'}\n"
                    f"   🆔 آیدی: {admin_id}\n"
                    f"   📌 یوزرنیم: {username}\n"
                    f"   📅 تاریخ اضافه شدن: {add_date}\n"
                    f"   ➕ اضافه شده توسط: {added_by}\n"
                    f"   ⚠️ اطلاعات به روز نیست\n"
                    f"   --------------------------\n"
                )
                counter += 1
                continue

            # اگر لیست خیلی طولانی شد، آن را تقسیم کنیم
            if counter % 5 == 0:
                await message.answer(admins_list)
                admins_list = "ادامه لیست ادمین‌ها:\n\n"

        if admins_list.strip():
            await message.answer(
                admins_list,
                reply_markup=await get_admin_keyboard()
            )
    except Exception as e:
        await message.answer(
            f"⚠️ خطا در نمایش لیست ادمین‌ها: {str(e)}",
            reply_markup=await get_admin_keyboard()
        )

async def handle_temp_unblock_user(message: types.Message, state: FSMContext):
    """شروع فرآیند رفع مسدودیت موقت"""
    try:
        await state.set_state(AdminStates.WAITING_FOR_TEMP_UNBLOCK_INPUT)
        await message.answer(
            "لطفاً آیدی عددی کاربر را برای رفع مسدودیت موقت وارد کنید:\n\n"
            "⚠️ فقط آیدی عددی قابل قبول است\n"
            "برای یافتن آیدی عددی کاربر می‌توانید از ربات @useridinfobot استفاده کنید\n\n"
            "برای لغو عملیات از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )
    except Exception as e:
        await message.answer(
            f"خطا در شروع فرآیند رفع مسدودیت موقت: {str(e)}",
            reply_markup=await get_admin_keyboard()
        )
        await state.clear()

async def process_temp_unblock_input(message: types.Message, state: FSMContext, bot, admins, user_blocks, DATA_DIR):
    """پردازش اطلاعات ورودی برای رفع مسدودیت موقت"""
    try:
        # بررسی اگر کاربر روی بازگشت کلیک کرده
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.clear()
            await message.answer(
                "عملیات رفع مسدودیت موقت لغو شد.",
                reply_markup=await get_admin_keyboard()
            )
            return

        user_input = message.text.strip()
        
        # بررسی اینکه ورودی فقط عدد باشد
        if not user_input.isdigit():
            await message.answer(
                "❌ فرمت آیدی نامعتبر!\n"
                "لطفاً فقط آیدی عددی کاربر را وارد کنید.\n\n"
                "برای یافتن آیدی عددی کاربر می‌توانید از ربات @useridinfobot استفاده کنید.",
                reply_markup=await get_cancel_keyboard()
            )
            return

        user_id = int(user_input)
        
        # اعتبارسنجی آیدی کاربر
        try:
            user = await bot.get_chat(user_id)
            username = user.username or "ندارد"
        except Exception as e:
            await message.answer(
                f"❌ کاربر با آیدی {user_id} یافت نشد!\n"
                "لطفاً آیدی عددی معتبر وارد کنید.",
                reply_markup=await get_cancel_keyboard()
            )
            return
        
        # بررسی اینکه کاربر در لیست مسدودیت‌های موقت باشد
        if user_id not in user_blocks:
            await message.answer(
                f"ℹ️ کاربر با آیدی {user_id} در لیست مسدودیت‌های موقت نیست.",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        
        # ذخیره اطلاعات کاربر برای مرحله بعدی
        await state.update_data({
            'user_id_to_temp_unblock': user_id,
            'username': username,
            'original_block_time': user_blocks[user_id].isoformat()
        })
        
        # درخواست دلیل از ادمین
        await state.set_state(AdminStates.WAITING_FOR_TEMP_UNBLOCK_REASON)
        await message.answer(
            "لطفاً دلیل رفع مسدودیت موقت این کاربر را وارد کنید:\n\n"
            "🍀 این توضیح فقط برای سازنده ربات ارسال خواهد شد.",
            reply_markup=await get_cancel_keyboard()
        )
        
    except Exception as e:
        await message.answer(
            f"⚠️ خطا در پردازش درخواست: {str(e)}\n\n"
            "لطفاً مجدداً تلاش کنید.",
            reply_markup=await get_admin_keyboard()
        )
        await state.clear()

async def process_temp_unblock_reason(message: types.Message, state: FSMContext, bot, admins, user_blocks, DATA_DIR, ADMIN_IDM):
    """پردازش دلیل رفع مسدودیت موقت"""
    try:
        # بررسی اگر کاربر روی بازگشت کلیک کرده
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.clear()
            await message.answer(
                "عملیات رفع مسدودیت موقت لغو شد.",
                reply_markup=await get_admin_keyboard()
            )
            return

        reason = message.text.strip()
        if len(reason) < 5:
            await message.answer(
                "❌ دلیل باید حداقل ۵ حرف داشته باشد! لطفاً مجدداً وارد کنید:",
                reply_markup=await get_cancel_keyboard()
            )
            return

        # دریافت اطلاعات ذخیره شده از مرحله قبل
        data = await state.get_data()
        user_id = data['user_id_to_temp_unblock']
        username = data['username']
        original_block_time = data['original_block_time']
        
        # رفع مسدودیت موقت کاربر
        del user_blocks[user_id]
        
        # ذخیره تغییرات
        try:
            with open(os.path.join(DATA_DIR, "user_blocks.json"), 'w', encoding='utf-8') as f:
                json.dump(
                    {user_id: block_time.isoformat() for user_id, block_time in user_blocks.items()},
                    f,
                    ensure_ascii=False,
                    indent=2
                )
        except Exception as e:
            await message.answer(
                f"❌ خطا در ذخیره تغییرات: {str(e)}\n\n"
                "مسدودیت موقت کاربر رفع شد اما تغییرات ذخیره نشد!",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        
        # اطلاع به ادمین
        await message.answer(
            f"✅ مسدودیت موقت کاربر زیر با موفقیت رفع شد:\n\n"
            f"🆔 آیدی: {user_id}\n"
            f"👤 یوزرنیم: @{username}",
            reply_markup=await get_admin_keyboard()
        )
        
        # ارسال دلیل به سازنده
        # try:
        await bot.send_message(
            ADMIN_IDM,
            f"📌 گزارش رفع مسدودیت موقت\n\n"
            f"👤 کاربر: @{username} (آیدی: {user_id})\n"
            f"⏳ زمان مسدودیت اصلی: {original_block_time}\n"
            f"🔄 رفع مسدودیت توسط: @{message.from_user.username} (آیدی: {message.from_user.id})\n"
            f"📝 دلیل: {reason}\n"
            f"🕒 زمان رفع مسدودیت: {datetime.now().strftime('%Y/%m/%d %H:%M')}"
        )
        
        # اطلاع به کاربر
        try:
            await bot.send_message(
                user_id,
                "🎉 محدودیت زمانی شما توسط ادمین رفع شد و می‌توانید از ربات استفاده کنید.\n\n"
                "🍀 لطفاً به یاد داشته باشید که در صورت تکرار تخلف، ممکن است دوباره محدود شوید."
            )
        except Exception as e:
            await message.answer(
                f"⚠️ نتوانستم به کاربر پیام رفع محدودیت را ارسال کنم. خطا: {str(e)}",
                reply_markup=await get_admin_keyboard()
            )
        
        await state.clear()
        
    except Exception as e:
        await message.answer(
            f"⚠️ خطا در پردازش دلیل: {str(e)}\n\n"
            "لطفاً مجدداً تلاش کنید.",
            reply_markup=await get_admin_keyboard()
        )
        await state.clear()

async def show_blocked_users(message: types.Message, bot, blocked_users, DATA_DIR):
    """نمایش لیست کاربران بلاک شده"""
    try:
        if not blocked_users:
            await message.answer(
                "⭕ هیچ کاربری بلاک نشده است.",
                reply_markup=await get_admin_keyboard()
            )
            return

        # بارگذاری مجدد لیست از فایل برای اطمینان
        try:
            with open(os.path.join(DATA_DIR, "blocked_users.json"), 'r', encoding='utf-8') as f:
                blocked_users = set(json.load(f).get('blocked_users', []))
        except Exception as e:
            await message.answer(
                f"⚠️ خطا در بارگذاری لیست بلاک شده‌ها: {str(e)}",
                reply_markup=await get_admin_keyboard()
            )
            return

        blocked_list = "📜 لیست کاربران بلاک شده:\n\n"
        counter = 1
        
        for user_id in blocked_users:
            try:
                user = await bot.get_chat(user_id)
                username = f"@{user.username}" if user.username else "بدون یوزرنیم"
                blocked_list += f"{counter}. 🆔 {user_id} | 👤 {username}\n"
                counter += 1
            except Exception as e:
                blocked_list += f"{counter}. 🆔 {user_id} | ⚠️ اطلاعات کاربر در دسترس نیست\n"
                counter += 1
                continue

            # اگر لیست خیلی طولانی شد، آن را تقسیم کنیم
            if counter % 20 == 0:
                await message.answer(blocked_list)
                blocked_list = "ادامه لیست:\n\n"

        if blocked_list.strip():
            await message.answer(
                blocked_list,
                reply_markup=await get_admin_keyboard()
            )
    except Exception as e:
        await message.answer(
            f"⚠️ خطا در نمایش لیست کاربران بلاک شده: {str(e)}",
            reply_markup=await get_admin_keyboard()
        )

async def handle_block_user(message: types.Message, state: FSMContext):
    """شروع فرآیند بلاک کاربر"""
    try:
        await state.set_state(AdminStates.WAITING_FOR_BLOCK_INPUT)
        await message.answer(
            "لطفاً آیدی عددی کاربر را برای بلاک کردن وارد کنید:\n\n"
            "⚠️ فقط آیدی عددی قابل قبول است\n"
            "برای یافتن آیدی عددی کاربر می‌توانید از ربات @useridinfobot استفاده کنید\n\n"
            "برای لغو عملیات از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )
    except Exception as e:
        await message.answer(
            f"خطا در شروع فرآیند بلاک: {str(e)}",
            reply_markup=await get_admin_keyboard()
        )
        await state.clear()

async def handle_unblock_user(message: types.Message, state: FSMContext):
    """شروع فرآیند آنبلاک کاربر"""
    try:
        await state.set_state(AdminStates.WAITING_FOR_UNBLOCK_INPUT)
        await message.answer(
            "لطفاً آیدی عددی کاربر را برای آنبلاک کردن وارد کنید:\n\n"
            "⚠️ فقط آیدی عددی قابل قبول است\n"
            "برای یافتن آیدی عددی کاربر می‌توانید از ربات @useridinfobot استفاده کنید\n\n"
            "برای لغو عملیات از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )
    except Exception as e:
        await message.answer(
            f"خطا در شروع فرآیند آنبلاک: {str(e)}",
            reply_markup=await get_admin_keyboard()
        )
        await state.clear()

async def validate_user_id(bot, user_id: int):
    """اعتبارسنجی آیدی کاربر"""
    try:
        user = await bot.get_chat(user_id)
        return True, user
    except Exception as e:
        return False, None

async def process_block_input(message: types.Message, state: FSMContext, bot, admins, blocked_users, DATA_DIR):
    """پردازش اطلاعات ورودی برای بلاک کاربر"""
    try:
        # بررسی اگر کاربر روی بازگشت کلیک کرده
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.clear()
            await message.answer(
                "عملیات بلاک کردن کاربر لغو شد.",
                reply_markup=await get_admin_keyboard()
            )
            return

        user_input = message.text.strip()
        
        # بررسی اینکه ورودی فقط عدد باشد
        if not user_input.isdigit():
            await message.answer(
                "❌ فرمت آیدی نامعتبر!\n"
                "لطفاً فقط آیدی عددی کاربر را وارد کنید.\n\n"
                "برای یافتن آیدی عددی کاربر می‌توانید از ربات @useridinfobot استفاده کنید.",
                reply_markup=await get_cancel_keyboard()
            )
            return

        user_id = int(user_input)
        
        # اعتبارسنجی آیدی کاربر
        is_valid, user = await validate_user_id(bot, user_id)
        if not is_valid:
            await message.answer(
                f"❌ کاربر با آیدی {user_id} یافت نشد!\n"
                "لطفاً آیدی عددی معتبر وارد کنید.",
                reply_markup=await get_cancel_keyboard()
            )
            return
        
        username = user.username or "ندارد"
        
        # بررسی اینکه کاربر ادمین نباشد
        if user_id in admins:
            await message.answer(
                "❌ نمی‌توانید ادمین‌ها را بلاک کنید!",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        
        # بررسی اینکه کاربر از قبل بلاک نشده باشد
        if user_id in blocked_users:
            await message.answer(
                f"ℹ️ کاربر با آیدی {user_id} از قبل بلاک شده است.",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        
        # ذخیره اطلاعات کاربر برای مرحله بعدی
        await state.update_data({
            'user_id_to_block': user_id,
            'username': username
        })
        
        # درخواست دلیل از ادمین
        await state.set_state(AdminStates.WAITING_FOR_BLOCK_REASON)
        await message.answer(
            "لطفاً دلیل بلاک کردن این کاربر را وارد کنید:\n\n"
            "🍀 این توضیح فقط برای سازنده ربات ارسال خواهد شد.",
            reply_markup=await get_cancel_keyboard()
        )
        
    except Exception as e:
        await message.answer(
            f"⚠️ خطا در پردازش درخواست: {str(e)}\n\n"
            "لطفاً مجدداً تلاش کنید.",
            reply_markup=await get_admin_keyboard()
        )
        await state.clear()


async def process_block_reason(message: types.Message, state: FSMContext, bot, admins, blocked_users, DATA_DIR, ADMIN_IDM):
    """پردازش دلیل بلاک کاربر"""
    try:
        # بررسی اگر کاربر روی بازگشت کلیک کرده
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.clear()
            await message.answer(
                "عملیات بلاک کردن کاربر لغو شد.",
                reply_markup=await get_admin_keyboard()
            )
            return

        reason = message.text.strip()
        if len(reason) < 5:
            await message.answer(
                "❌ دلیل باید حداقل ۵ حرف داشته باشد! لطفاً مجدداً وارد کنید:",
                reply_markup=await get_cancel_keyboard()
            )
            return

        # دریافت اطلاعات ذخیره شده از مرحله قبل
        data = await state.get_data()
        user_id = data['user_id_to_block']
        username = data['username']
        
        # بلاک کردن کاربر
        blocked_users.add(user_id)
        
        # ذخیره لیست بلاک شده‌ها
        try:
            with open(os.path.join(DATA_DIR, "blocked_users.json"), 'w', encoding='utf-8') as f:
                json.dump({'blocked_users': list(blocked_users)}, f, ensure_ascii=False, indent=2)
        except Exception as e:
            await message.answer(
                f"❌ خطا در ذخیره تغییرات: {str(e)}\n\n"
                "کاربر بلاک شد اما تغییرات ذخیره نشد!",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        
        # اطلاع به ادمین
        await message.answer(
            f"✅ کاربر زیر با موفقیت بلاک شد:\n\n"
            f"🆔 آیدی: {user_id}\n"
            f"👤 یوزرنیم: @{username}\n\n"
            f"تعداد کاربران بلاک شده: {len(blocked_users)}",
            reply_markup=await get_admin_keyboard()
        )
        
        # ارسال دلیل به سازنده
        # try:
        await bot.send_message(
            ADMIN_IDM,
            f"📌 گزارش بلاک کاربر\n\n"
            f"👤 کاربر: @{username} (آیدی: {user_id})\n"
            f"🛑 بلاک شده توسط: @{message.from_user.username} (آیدی: {message.from_user.id})\n"
            f"📝 دلیل: {reason}\n"
            f"🕒 زمان: {datetime.now().strftime('%Y/%m/%d %H:%M')}"
        )
        
        # اطلاع به کاربر بلاک شده
        try:
            await bot.send_message(
                user_id,
                "⛔ شما توسط ادمین بلاک شدید و نمی‌توانید از ربات استفاده کنید.\n\n"
                "🍀 در صورت نیاز به توضیح با پشتیبانی تماس بگیرید."
            )
        except Exception as e:
            await message.answer(
                f"⚠️ نتوانستم به کاربر پیام بلاک شدن را ارسال کنم. خطا: {str(e)}",
                reply_markup=await get_admin_keyboard()
            )
        
        await state.clear()
        
    except Exception as e:
        await message.answer(
            f"⚠️ خطا در پردازش دلیل: {str(e)}\n\n"
            "لطفاً مجدداً تلاش کنید.",
            reply_markup=await get_admin_keyboard()
        )
        await state.clear()


async def process_unblock_input(message: types.Message, state: FSMContext, bot, admins, blocked_users, DATA_DIR):
    """پردازش اطلاعات ورودی برای آنبلاک کاربر"""
    try:
        # بررسی اگر کاربر روی بازگشت کلیک کرده
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.clear()
            await message.answer(
                "عملیات آنبلاک کردن کاربر لغو شد.",
                reply_markup=await get_admin_keyboard()
            )
            return

        user_input = message.text.strip()
        
        # بررسی اینکه ورودی فقط عدد باشد
        if not user_input.isdigit():
            await message.answer(
                "❌ فرمت آیدی نامعتبر!\n"
                "لطفاً فقط آیدی عددی کاربر را وارد کنید.\n\n"
                "برای یافتن آیدی عددی کاربر می‌توانید از ربات @useridinfobot استفاده کنید.",
                reply_markup=await get_cancel_keyboard()
            )
            return

        user_id = int(user_input)
        
        # اعتبارسنجی آیدی کاربر
        is_valid, user = await validate_user_id(bot, user_id)
        if not is_valid:
            await message.answer(
                f"❌ کاربر با آیدی {user_id} یافت نشد!\n"
                "لطفاً آیدی عددی معتبر وارد کنید.",
                reply_markup=await get_cancel_keyboard()
            )
            return
        
        username = user.username or "ندارد"
        
        # بررسی اینکه کاربر از قبل بلاک شده باشد
        if user_id not in blocked_users:
            await message.answer(
                f"ℹ️ کاربر با آیدی {user_id} از قبل بلاک نشده است.",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        
        # ذخیره اطلاعات کاربر برای مرحله بعدی
        await state.update_data({
            'user_id_to_unblock': user_id,
            'username': username
        })
        
        # درخواست دلیل از ادمین
        await state.set_state(AdminStates.WAITING_FOR_UNBLOCK_REASON)
        await message.answer(
            "لطفاً دلیل آنبلاک کردن این کاربر را وارد کنید:\n\n"
            "🍀 این توضیح فقط برای سازنده ربات ارسال خواهد شد.",
            reply_markup=await get_cancel_keyboard()
        )
        
    except Exception as e:
        await message.answer(
            f"⚠️ خطا در پردازش درخواست: {str(e)}\n\n"
            "لطفاً مجدداً تلاش کنید.",
            reply_markup=await get_admin_keyboard()
        )
        await state.clear()


async def process_unblock_reason(message: types.Message, state: FSMContext, bot, admins, blocked_users, DATA_DIR, ADMIN_IDM):
    """پردازش دلیل آنبلاک کاربر"""
    try:
        # بررسی اگر کاربر روی بازگشت کلیک کرده
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.clear()
            await message.answer(
                "عملیات آنبلاک کردن کاربر لغو شد.",
                reply_markup=await get_admin_keyboard()
            )
            return

        reason = message.text.strip()
        if len(reason) < 5:
            await message.answer(
                "❌ دلیل باید حداقل ۵ حرف داشته باشد! لطفاً مجدداً وارد کنید:",
                reply_markup=await get_cancel_keyboard()
            )
            return

        # دریافت اطلاعات ذخیره شده از مرحله قبل
        data = await state.get_data()
        user_id = data['user_id_to_unblock']
        username = data['username']
        
        # آنبلاک کردن کاربر
        blocked_users.remove(user_id)
        
        # ذخیره لیست بلاک شده‌ها
        try:
            with open(os.path.join(DATA_DIR, "blocked_users.json"), 'w', encoding='utf-8') as f:
                json.dump({'blocked_users': list(blocked_users)}, f, ensure_ascii=False, indent=2)
        except Exception as e:
            await message.answer(
                f"❌ خطا در ذخیره تغییرات: {str(e)}\n\n"
                "کاربر آنبلاک شد اما تغییرات ذخیره نشد!",
                reply_markup=await get_admin_keyboard()
            )
            await state.clear()
            return
        
        # اطلاع به ادمین
        await message.answer(
            f"✅ کاربر زیر با موفقیت آنبلاک شد:\n\n"
            f"🆔 آیدی: {user_id}\n"
            f"👤 یوزرنیم: @{username}\n\n"
            f"تعداد کاربران بلاک شده: {len(blocked_users)}",
            reply_markup=await get_admin_keyboard()
        )
        
        # ارسال دلیل به سازنده
        # try:
        await bot.send_message(
            ADMIN_IDM,
            f"📌 گزارش آنبلاک کاربر\n\n"
            f"👤 کاربر: @{username} (آیدی: {user_id})\n"
            f"✅ آنبلاک شده توسط: @{message.from_user.username} (آیدی: {message.from_user.id})\n"
            f"📝 دلیل: {reason}\n"
            f"🕒 زمان: {datetime.now().strftime('%Y/%m/%d %H:%M')}"
        )
        # except Exception as e:
        #     logger.error(f"Error sending unblock reason to creator: {e}")
        
        # اطلاع به کاربر آنبلاک شده
        try:
            await bot.send_message(
                user_id,
                "🎉 شما توسط ادمین آنبلاک شدید و می‌توانید از ربات استفاده کنید.\n\n"
                "🍀 با تشکر از همکاری شما."
            )
        except Exception as e:
            await message.answer(
                f"⚠️ نتوانستم به کاربر پیام آنبلاک شدن را ارسال کنم. خطا: {str(e)}",
                reply_markup=await get_admin_keyboard()
            )
        
        await state.clear()
        
    except Exception as e:
        await message.answer(
            f"⚠️ خطا در پردازش دلیل: {str(e)}\n\n"
            "لطفاً مجدداً تلاش کنید.",
            reply_markup=await get_admin_keyboard()
        )
        await state.clear()


def register_admin_handlers(dp, bot, admins, blocked_users, user_blocks, DATA_DIR, ADMIN_ID, ADMIN_IDM, logger, SUPPORT_USERNAME, 
                          CHANNEL_ID, channel_posts_store, user_data_store, rating_votes, save_all_data, export_users_to_excel, generate_bot_statistics):
    """ثبت تمام هندلرهای مربوط به پنل ادمین"""
    
    # متغیر موقت برای ذخیره پیام‌ها
    pending_messages = {}
    
    # بارگذاری اطلاعات ادمین‌ها
    admins_data = {}
    try:
        admins_data_file = os.path.join(DATA_DIR, "admins_data.json")
        if os.path.exists(admins_data_file):
            with open(admins_data_file, 'r', encoding='utf-8') as f:
                admins_data = json.load(f)
    except Exception as e:
        print(f"Error loading admins data: {e}")


    @dp.message(F.text == "👥 مدیریت کاربران", F.from_user.id.in_(admins))
    async def handle_user_management(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        await state.set_state(UserManagementStates.MAIN_MENU)
        await message.answer(
            "منوی مدیریت کاربران:",
            reply_markup=await get_user_management_keyboard()
        )
        
    @dp.message(F.text == "🔙 بازگشت به منوی اصلی", F.from_user.id.in_(admins))
    async def return_to_main_menu(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        current_state = await state.get_state()
        if current_state in [
            UserManagementStates.MAIN_MENU,
            UserManagementStates.SELECT_RECIPIENTS,
            UserManagementStates.ENTER_USER_IDS,
            UserManagementStates.CONFIRM_MESSAGE,
            ContentManagementStates.MAIN_MENU,
            ContentManagementStates.ADD_FILTER,
            ContentManagementStates.REMOVE_FILTER]:
            await state.clear()
            await message.answer(
                "منوی اصلی ادمین:",
                reply_markup=await get_admin_keyboard()
            )
        else:
            await state.clear()
            await message.answer(
                "عملیات کنونی لغو شد.",
                reply_markup=await get_admin_keyboard()
            )


    @dp.message(F.text == "🚫 بلاک کاربر", F.from_user.id.in_(admins), UserManagementStates.MAIN_MENU)
    async def admin_block_user(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        await state.set_state(UserManagementStates.BLOCK_USER)
        await handle_block_user(message, state)
        
    @dp.message(F.text == "✅ آنبلاک کاربر", F.from_user.id.in_(admins), UserManagementStates.MAIN_MENU)
    async def admin_unblock_user(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        await state.set_state(UserManagementStates.UNBLOCK_USER)
        await handle_unblock_user(message, state)
    
    @dp.message(AdminStates.WAITING_FOR_BLOCK_INPUT, F.from_user.id.in_(admins))
    async def handle_block_input(message: types.Message, state: FSMContext):
        await process_block_input(
            message, 
            state, 
            bot, 
            admins, 
            blocked_users, 
            DATA_DIR
        )
    
    @dp.message(AdminStates.WAITING_FOR_UNBLOCK_INPUT, F.from_user.id.in_(admins))
    async def handle_unblock_input(message: types.Message, state: FSMContext):
        await process_unblock_input(
            message, 
            state, 
            bot, 
            admins, 
            blocked_users, 
            DATA_DIR
        )

    @dp.message(F.text == "📜 لیست کاربران بلاک شده", F.from_user.id.in_(admins), UserManagementStates.MAIN_MENU)
    async def show_blocked_users_handler(message: types.Message):
        await delete_message_safely(message)
        await show_blocked_users(message, bot, blocked_users, DATA_DIR)

    @dp.message(F.text == "⏳ رفع مسدودیت موقت", F.from_user.id.in_(admins), UserManagementStates.MAIN_MENU)
    async def admin_temp_unblock_user(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        await state.set_state(UserManagementStates.TEMP_UNBLOCK_USER)
        await handle_temp_unblock_user(message, state)
    
    @dp.message(AdminStates.WAITING_FOR_TEMP_UNBLOCK_INPUT, F.from_user.id.in_(admins))
    async def handle_temp_unblock_input(message: types.Message, state: FSMContext):
        await process_temp_unblock_input(
            message, 
            state, 
            bot, 
            admins, 
            user_blocks, 
            DATA_DIR
        )


    @dp.message(F.text == "👑 مدیریت ادمین‌ها", F.from_user.id.in_(admins))
    async def handle_admin_management(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """ورود به منوی مدیریت ادمین‌ها"""
        await state.set_state(AdminManagementStates.MAIN_MENU)
        sent_message = await message.answer(
            "منوی مدیریت ادمین‌ها:",
            reply_markup=await get_admin_management_keyboard()
        )

    @dp.message(F.text == "➕ افزودن ادمین", F.from_user.id.in_(admins), AdminManagementStates.MAIN_MENU)
    async def admin_add_admin(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        if message.from_user.id != ADMIN_IDM:
            await message.answer("⛔ فقط سازنده می‌تواند از این بخش استفاده کند!", reply_markup=await get_admin_management_keyboard())
            return
        await state.set_state(AdminManagementStates.ADD_ADMIN)
        await handle_add_admin(message, state)

    @dp.message(F.text == "➖ عزل ادمین", F.from_user.id.in_(admins), AdminManagementStates.MAIN_MENU)
    async def admin_remove_admin(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        if message.from_user.id != ADMIN_IDM:
            await message.answer("⛔ فقط سازنده می‌تواند از این بخش استفاده کند!", reply_markup=await get_admin_management_keyboard())
            return
        await state.set_state(AdminManagementStates.REMOVE_ADMIN)
        await handle_remove_admin(message, state)

    @dp.message(F.text == "👥 لیست ادمین‌ها", F.from_user.id.in_(admins), AdminManagementStates.MAIN_MENU)
    async def admin_list_admins(message: types.Message):
        await delete_message_safely(message)
        if message.from_user.id != ADMIN_IDM:
            await message.answer("⛔ فقط سازنده می‌تواند از این بخش استفاده کند!", reply_markup=await get_admin_management_keyboard())
            return
        await show_admins_list(message, bot, admins, admins_data)
        await message.answer(
            "منوی مدیریت ادمین‌ها:",
            reply_markup=await get_admin_management_keyboard()
        )
    
    @dp.message(AdminStates.WAITING_FOR_ADD_ADMIN_INPUT, F.from_user.id.in_(admins))
    async def handle_add_admin_input(message: types.Message, state: FSMContext):
        await process_add_admin_input(
            message, 
            state, 
            bot, 
            admins, 
            admins_data, 
            DATA_DIR,
            ADMIN_ID  # اضافه شده
        )
    
    @dp.message(AdminStates.WAITING_FOR_REMOVE_ADMIN_INPUT, F.from_user.id.in_(admins))
    async def handle_remove_admin_input(message: types.Message, state: FSMContext):
        await process_remove_admin_input(
            message, 
            state, 
            bot, 
            admins, 
            admins_data, 
            DATA_DIR,
            ADMIN_ID  # اضافه شده
        )

    @dp.message(F.text == "👤 نمایش مشخصات من", F.from_user.id.in_(admins))
    async def show_my_info(message: types.Message):
        await delete_message_safely(message)
        """نمایش آیدی و مشخصات ادمین"""
        try:
            user = message.from_user
            user_id = user.id
            full_name = f"{user.first_name or ''} {user.last_name or ''}".strip()
            username = f"@{user.username}" if user.username else "بدون یوزرنیم"
            
            # بررسی وضعیت ادمین
            is_admin = user_id in admins
            admin_status = "✅ ادمین" if is_admin else "❌ کاربر عادی"

            # بررسی وضعیت بلاک
            is_blocked = user_id in blocked_users
            block_status = "🔴 بلاک شده" if is_blocked else "🟢 فعال"

            response = (
                f"👤 <b>مشخصات شما:</b>\n\n"
                f"🆔 آیدی عددی: <code>{user_id}</code>\n"
                f"📌 نام کامل: {full_name}\n"
                f"🔗 یوزرنیم: {username}\n"
                f"👮 وضعیت: {admin_status}\n"
                f"🚫 وضعیت دسترسی: {block_status}\n\n"
            )

            await message.answer(response, parse_mode="HTML")

        except Exception as e:
            logger.error(f"Error in show_my_info: {e}")
            await message.answer("⚠️ خطا در دریافت اطلاعات!", reply_markup=await get_admin_keyboard())

    @dp.message(F.text == "🔍 یافتن آیدی عددی", F.from_user.id.in_(admins))
    async def handle_find_user_id(message: types.Message):
        await delete_message_safely(message)
        """هدایت ادمین به ربات @useridinfobot برای یافتن آیدی عددی"""
        try:
            # ایجاد یک دکمه اینلاین برای هدایت به ربات @useridinfobot
            keyboard = InlineKeyboardMarkup(
                inline_keyboard=[
                    [InlineKeyboardButton(
                        text="🔍 یافتن آیدی عددی با @useridinfobot", 
                        url="https://t.me/useridinfobot"
                    )]
                ]
            )

            await message.answer(
                "برای یافتن آیدی عددی یک کاربر، روی دکمه زیر کلیک کنید:",
                reply_markup=keyboard
            )
        except Exception as e:
            logger.error(f"Error in handle_find_user_id: {e}")
            await message.answer(
                "⚠️ خطا در هدایت به ربات یافتن آیدی!",
                reply_markup=await get_admin_keyboard()
            )


    @dp.message(F.text == "📝 مدیریت آگهی‌ها", F.from_user.id.in_(admins))
    async def handle_content_management(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """ورود به منوی مدیریت مطالب"""
        await state.set_state(ContentManagementStates.MAIN_MENU)
        await message.answer(
            "منوی مدیریت مطالب:",
            reply_markup=await get_content_management_keyboard()
        )
        

    @dp.message(F.text == "➕ افزودن فیلتر", F.from_user.id.in_(admins), ContentManagementStates.MAIN_MENU)
    async def handle_add_filter(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        await state.set_state(ContentManagementStates.ADD_FILTER)
        await message.answer(
            "لطفاً کلمه یا عبارت مورد نظر برای افزودن به لیست فیلتر را ارسال کنید:\n\n"
            "🍀 می‌توانید چند کلمه را در خطوط جداگانه وارد کنید.\n"
            "مثال:\n"
            "کلمه اول\n"
            "کلمه دوم\n"
            "عبارت سوم\n\n"
            "برای لغو از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )

    @dp.message(F.text == "➖ حذف فیلتر", F.from_user.id.in_(admins), ContentManagementStates.MAIN_MENU)
    async def handle_remove_filter(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        await state.set_state(ContentManagementStates.REMOVE_FILTER)
        await message.answer(
            "لطفاً کلمه یا عبارت مورد نظر برای حذف از لیست فیلتر را ارسال کنید:\n\n"
            "🍀 می‌توانید چند کلمه را در خطوط جداگانه وارد کنید.\n"
            "مثال:\n"
            "کلمه اول\n"
            "کلمه دوم\n"
            "عبارت سوم\n\n"
            "برای لغو از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )

    @dp.message(F.text == "📜 لیست کلمات فیلتر", F.from_user.id.in_(admins), ContentManagementStates.MAIN_MENU)
    async def handle_show_filters(message: types.Message):
        await delete_message_safely(message)
        # if message.from_user.id != ADMIN_IDM:
        #     await message.answer("⛔ فقط سازنده می‌تواند لیست کلمات فیلتر را مشاهده کند!")
        #     return

        if not banned_words:
            await message.answer("ℹ️ لیست کلمات فیلتر خالی است.")
            return

        words_list = "\n".join(f"• {i+1}. {word}" for i, word in enumerate(banned_words))
        response = f"📜 لیست کلمات فیلتر شده:\n\n{words_list}\n\n🔢 تعداد کل: {len(banned_words)} کلمه"
        
        if len(response) > 4000:
            parts = [response[i:i+4000] for i in range(0, len(response), 4000)]
            for part in parts:
                await message.answer(part)
                await asyncio.sleep(1)
        else:
            await message.answer(response)
        
        await message.answer(
            "منوی مدیریت مطالب:",
            reply_markup=await get_content_management_keyboard()
        )

    # هندلرهای پردازش کلمات فیلتر
    @dp.message(ContentManagementStates.ADD_FILTER, F.from_user.id.in_(admins))
    async def process_add_filter_word(message: types.Message, state: FSMContext):
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.set_state(ContentManagementStates.MAIN_MENU)
            await message.answer(
                "منوی مدیریت مطالب:",
                reply_markup=await get_content_management_keyboard()
            )
            return

        # دریافت متن و تقسیم به خطوط مختلف
        input_text = message.text.strip()
        words = [line.strip().lower() for line in input_text.split('\n') if line.strip()]
        
        added_words = []
        duplicate_words = []
        
        for word in words:
            if word in banned_words:
                duplicate_words.append(word)
            else:
                banned_words.append(word)
                added_words.append(word)
        
        # ذخیره تغییرات
        if added_words:
            if save_banned_words(banned_words):
                response = f"✅ کلمات زیر با موفقیت به لیست فیلتر اضافه شدند:\n"
                response += "\n".join(f"• {word}" for word in added_words)
                
                if duplicate_words:
                    response += f"\n\nℹ️ کلمات زیر از قبل در لیست وجود داشتند:\n"
                    response += "\n".join(f"• {word}" for word in duplicate_words)
            else:
                response = "❌ خطا در ذخیره تغییرات!"
        else:
            response = "ℹ️ هیچ کلمه جدیدی برای افزودن یافت نشد.\n"
            if duplicate_words:
                response += "کلمات زیر از قبل در لیست وجود داشتند:\n"
                response += "\n".join(f"• {word}" for word in duplicate_words)
        
        await message.answer(response)
        
        await state.set_state(ContentManagementStates.MAIN_MENU)
        await message.answer(
            "منوی مدیریت مطالب:",
            reply_markup=await get_content_management_keyboard()
        )



    @dp.message(ContentManagementStates.REMOVE_FILTER, F.from_user.id.in_(admins))
    async def process_remove_filter_word(message: types.Message, state: FSMContext):
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.set_state(ContentManagementStates.MAIN_MENU)
            await message.answer(
                "منوی مدیریت مطالب:",
                reply_markup=await get_content_management_keyboard()
            )
            return

        # دریافت متن و تقسیم به خطوط مختلف
        input_text = message.text.strip()
        words = [line.strip().lower() for line in input_text.split('\n') if line.strip()]
        
        removed_words = []
        not_found_words = []
        
        for word in words:
            if word in banned_words:
                banned_words.remove(word)
                removed_words.append(word)
            else:
                not_found_words.append(word)
        
        # ذخیره تغییرات
        if removed_words:
            if save_banned_words(banned_words):
                response = f"✅ کلمات زیر با موفقیت از لیست فیلتر حذف شدند:\n"
                response += "\n".join(f"• {word}" for word in removed_words)
                
                if not_found_words:
                    response += f"\n\nℹ️ کلمات زیر در لیست فیلتر وجود نداشتند:\n"
                    response += "\n".join(f"• {word}" for word in not_found_words)
            else:
                response = "❌ خطا در ذخیره تغییرات!"
        else:
            response = "ℹ️ هیچ کلمه‌ای برای حذف یافت نشد.\n"
            if not_found_words:
                response += "کلمات زیر در لیست فیلتر وجود نداشتند:\n"
                response += "\n".join(f"• {word}" for word in not_found_words)
        
        await message.answer(response)
        
        await state.set_state(ContentManagementStates.MAIN_MENU)
        await message.answer(
            "منوی مدیریت مطالب:",
            reply_markup=await get_content_management_keyboard()
        )

    @dp.message(F.text == "📩 مدیریت پیام‌ها", F.from_user.id.in_(admins))
    async def handle_message_management(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """مدیریت پیام‌های ربات"""
        await state.set_state(MessageManagementStates.MAIN_MENU)
        await message.answer(
            "منوی مدیریت پیام‌های ربات:",
            reply_markup=await get_message_management_keyboard()
        )

    @dp.message(F.text == "✏️ ویرایش خوشامد", F.from_user.id.in_(admins))
    async def edit_welcome_message(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """ویرایش متن خوشامدگویی"""
        if message.from_user.id != ADMIN_IDM:
            await message.answer("⛔ فقط سازنده می‌تواند این پیام را ویرایش کند!", reply_markup=await get_admin_keyboard())
            return
        await state.set_state(MessageManagementStates.EDIT_WELCOME)
        await message.answer(
            "لطفاً متن جدید خوشامدگویی را ارسال کنید:\n\n"
            "🍀 می‌توانید از متغیر {SUPPORT_USERNAME} برای یوزرنیم پشتیبانی استفاده کنید.\n\n"
            "برای لغو از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )

    @dp.message(F.text == "✏️ ویرایش پشتیبانی", F.from_user.id.in_(admins))
    async def edit_support_message(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """ویرایش متن پشتیبانی"""
        if message.from_user.id != ADMIN_IDM:
            await message.answer("⛔ فقط سازنده می‌تواند این پیام را ویرایش کند!", reply_markup=await get_admin_keyboard())
            return
        await state.set_state(MessageManagementStates.EDIT_SUPPORT)
        await message.answer(
            "لطفاً متن جدید پشتیبانی را ارسال کنید:\n\n"
            "🍀 می‌توانید از متغیر {SUPPORT_USERNAME} برای یوزرنیم پشتیبانی استفاده کنید.\n\n"
            "برای لغو از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )

    @dp.message(F.text == "✏️ ویرایش قوانین", F.from_user.id.in_(admins))
    async def edit_rules_message(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """ویرایش متن قوانین"""
        if message.from_user.id != ADMIN_IDM:
            await message.answer("⛔ فقط سازنده می‌تواند این پیام را ویرایش کند!", reply_markup=await get_admin_keyboard())
            return
        await state.set_state(MessageManagementStates.EDIT_RULES)
        await message.answer(
            "لطفاً متن جدید قوانین را ارسال کنید:\n\n"
            "برای لغو از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )

    @dp.message(F.text == "✏️ ویرایش راهنمای ادمین", F.from_user.id.in_(admins))
    async def edit_help_admin_message(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """ویرایش متن راهنمای ادمین"""
        if message.from_user.id != ADMIN_IDM:
            await message.answer("⛔ فقط سازنده می‌تواند این پیام را ویرایش کند!", reply_markup=await get_admin_keyboard())
            return
        await state.set_state(MessageManagementStates.EDIT_HELP_ADMIN)
        await message.answer(
            "لطفاً متن جدید راهنمای ادمین را ارسال کنید:\n\n"
            "برای لغو از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )

    @dp.message(MessageManagementStates.EDIT_WELCOME, F.from_user.id == ADMIN_IDM)
    async def process_new_welcome(message: types.Message, state: FSMContext):
        """پردازش متن جدید خوشامدگویی"""
        new_text = message.text
        bot_texts["welcome_text"] = new_text.replace("{SUPPORT_USERNAME}", SUPPORT_USERNAME)
        
        if save_bot_texts(bot_texts):
            await message.answer("✅ متن خوشامدگویی با موفقیت به‌روزرسانی شد!", reply_markup=await get_admin_keyboard())
        else:
            await message.answer("❌ خطا در ذخیره متن جدید!", reply_markup=await get_admin_keyboard())
        
        await state.clear()

    @dp.message(MessageManagementStates.EDIT_SUPPORT, F.from_user.id == ADMIN_IDM)
    async def process_new_support(message: types.Message, state: FSMContext):
        """پردازش متن جدید پشتیبانی"""
        new_text = message.text
        bot_texts["support_text"] = new_text.replace("{SUPPORT_USERNAME}", SUPPORT_USERNAME)
        
        if save_bot_texts(bot_texts):
            await message.answer("✅ متن پشتیبانی با موفقیت به‌روزرسانی شد!", reply_markup=await get_admin_keyboard())
        else:
            await message.answer("❌ خطا در ذخیره متن جدید!", reply_markup=await get_admin_keyboard())
        
        await state.clear()

    @dp.message(MessageManagementStates.EDIT_RULES, F.from_user.id == ADMIN_IDM)
    async def process_new_rules(message: types.Message, state: FSMContext):
        """پردازش متن جدید قوانین"""
        new_text = message.text
        bot_texts["rules_text"] = new_text
        
        if save_bot_texts(bot_texts):
            await message.answer("✅ متن قوانین با موفقیت به‌روزرسانی شد!", reply_markup=await get_admin_keyboard())
        else:
            await message.answer("❌ خطا در ذخیره متن جدید!", reply_markup=await get_admin_keyboard())
        
        await state.clear()

    @dp.message(MessageManagementStates.EDIT_HELP_ADMIN, F.from_user.id == ADMIN_IDM)
    async def process_new_help_admin(message: types.Message, state: FSMContext):
        """پردازش متن جدید راهنمای ادمین"""
        new_text = message.text
        bot_texts["helpadmin_text"] = new_text
        
        if save_bot_texts(bot_texts):
            await message.answer("✅ متن راهنمای ادمین با موفقیت به‌روزرسانی شد!", reply_markup=await get_admin_keyboard())
        else:
            await message.answer("❌ خطا در ذخیره متن جدید!", reply_markup=await get_admin_keyboard())
        
        await state.clear()


    @dp.message(F.text == "🗑️ حذف آگهی", F.from_user.id.in_(admins), ContentManagementStates.MAIN_MENU)
    async def handle_delete_memory(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """شروع فرآیند حذف آگهی"""
        await message.answer(
            "⚠️ یکی از روش‌های زیر را انتخاب کنید:\n\n"
            "1. لینک یا آیدی پیام آگهی را ارسال کنید\n"
            "   مثال: https://t.me/ShirazMemories/123 یا 123\n\n"
            "2. آگهی را از کانال فوروارد کنید\n\n"
            "برای لغو از دکمه 🔙 بازگشت به منوی اصلی استفاده کنید.",
            reply_markup=await get_cancel_keyboard()
        )
        await state.set_state(DeleteMemoryStates.waiting_for_memory_id)

    @dp.message(DeleteMemoryStates.waiting_for_memory_id, F.from_user.id.in_(admins), F.forward_from_chat)
    async def handle_forwarded_memory(message: types.Message, state: FSMContext):
        """پردازش آگهی فوروارد شده"""
        try:
            # بررسی اینکه پیام از کانال اصلی فوروارد شده باشد
            # print(message.forward_from_chat.id)
            # print(CHANNEL_ID)
            if message.forward_from_chat.id != CHANNEL_IDs:
                await message.answer("⚠️ فقط می‌توانید آگهی‌ها از کانال اصلی را فوروارد کنید!")
                return

            message_id = message.forward_from_message_id
            channel_media_id = f"{CHANNEL_ID}_{message_id}"
            
            if channel_media_id not in channel_posts_store:
                await message.answer("❌ آگهی با این مشخصات یافت نشد!")
                return

            memory_data = channel_posts_store[channel_media_id]

            # ذخیره اطلاعات در state
            await state.update_data({
                'message_id': message_id,
                'channel_media_id': channel_media_id,
                'memory_data': memory_data,
                'admin_id': message.from_user.id,
                'admin_name': message.from_user.full_name,
                'admin_username': message.from_user.username
            })

            # درخواست دلیل از ادمین
            await message.answer(
                "📝 لطفاً دلیل حذف این آگهی را وارد کنید:\n"
                "🍀 این توضیح برای کاربر و سایر ادمین‌ها ارسال خواهد شد.",
                reply_markup=await get_cancel_keyboard()
            )
            await state.set_state(DeleteMemoryStates.waiting_for_reason)
            
        except Exception as e:
            logger.error(f"Error processing forwarded memory: {e}")
            await message.answer("⚠️ خطا در پردازش آگهی فوروارد شده!")
            await state.clear()

    @dp.message(DeleteMemoryStates.waiting_for_memory_id, F.from_user.id.in_(admins))
    async def process_memory_id(message: types.Message, state: FSMContext):
        """پردازش آیدی/لینک آگهی"""
        try:
            # بررسی اگر کاربر روی بازگشت کلیک کرده
            if message.text == "🔙 بازگشت به منوی اصلی":
                await state.clear()
                await message.answer(
                    "عملیات حذف آگهی لغو شد.",
                    reply_markup=await get_content_management_keyboard()
                )
                return

            input_text = message.text.strip()
            
            try:
                # استخراج آیدی پیام از لینک یا متن مستقیم
                if input_text.startswith('http'):
                    message_id = int(input_text.split('/')[-1])
                else:
                    message_id = int(input_text)

                channel_media_id = f"{CHANNEL_ID}_{message_id}"
                
                if channel_media_id not in channel_posts_store:
                    await message.answer("❌ آگهی با این مشخصات یافت نشد!")
                    return

                memory_data = channel_posts_store[channel_media_id]

                await state.update_data({
                    'message_id': message_id,
                    'channel_media_id': channel_media_id,
                    'memory_data': memory_data,
                    'admin_id': message.from_user.id,
                    'admin_name': message.from_user.full_name,
                    'admin_username': message.from_user.username
                })

                await message.answer(
                    "📝 لطفاً دلیل حذف این آگهی را وارد کنید:\n"
                    "🍀 این توضیح برای کاربر و سایر ادمین‌ها ارسال خواهد شد.",
                    reply_markup=await get_cancel_keyboard()
                )
                await state.set_state(DeleteMemoryStates.waiting_for_reason)
                
            except ValueError:
                await message.answer("⚠️ آدرس یا آیدی پیام نامعتبر است! لطفاً مجدداً وارد کنید:")
            except Exception as e:
                logger.error(f"Error in process_memory_id: {e}")
                await message.answer("⚠️ خطا در پردازش درخواست! لطفاً مجدداً تلاش کنید.")

        except Exception as e:
            logger.error(f"Error in handle_delete_memory: {e}")
            await message.answer("⚠️ خطا در شروع فرآیند حذف!")
            await state.clear()




    def load_user_memories():
        """بارگذاری آگهی‌های کاربران از فایل"""
        try:
            if USER_MEMORIES_FILE.exists():
                with open(USER_MEMORIES_FILE, 'r', encoding='utf-8') as f:
                    data = json.load(f)
                    # تبدیل وضعیت‌های قدیمی به جدید
                    for user_id, memories in data.items():
                        for memory in memories:
                            if 'status' not in memory:
                                # اگر پیام در کانال وجود ندارد، آن را به عنوان حذف شده علامت بزنید
                                if 'message_id' in memory:
                                    try:
                                        message = bot.get_chat_message(CHANNEL_ID, memory['message_id'])
                                        memory['status'] = 'active'
                                    except:
                                        memory['status'] = 'deleted'
                                else:
                                    memory['status'] = 'active'
                    return data
        except Exception as e:
            logger.error(f"Error loading user memories: {e}")
        return {}

    def save_user_memories(data):
        """ذخیره آگهی‌های کاربران در فایل"""
        try:
            DATA_DIR.mkdir(exist_ok=True)
            with open(USER_MEMORIES_FILE, 'w', encoding='utf-8') as f:
                json.dump(data, f, ensure_ascii=False, indent=2)
        except Exception as e:
            logger.error(f"Error saving user memories: {e}")
















    @dp.message(DeleteMemoryStates.waiting_for_reason, F.from_user.id.in_(admins))
    async def process_deletion_reason(message: types.Message, state: FSMContext):
        """پردازش دلیل حذف و انجام عملیات حذف"""
        try:
            reason = message.text.strip()
            if len(reason) < 5:
                await message.answer("❌ دلیل باید حداقل ۵ حرف داشته باشد! لطفاً مجدداً وارد کنید:")
                return

            data = await state.get_data()
            if 'message_id' not in data:
                await state.clear()
                await message.answer("❌ اطلاعات جلسه از دست رفته! لطفاً مجدداً شروع کنید.")
                return

            message_id = data['message_id']
            channel_media_id = data['channel_media_id']
            memory_data = data['memory_data']
            admin_username = data.get('admin_username', 'ادمین')

            # 1. حذف پیام از کانال
            try:
                await bot.delete_message(
                    chat_id=CHANNEL_ID,
                    message_id=message_id
                )
            except Exception as e:
                logger.error(f"Error deleting message: {e}")
                await message.answer("⚠️ خطا در حذف پیام از کانال!")
                await state.clear()
                return

            # 2. به‌روزرسانی وضعیت در user_data_store
            user_id = memory_data.get('user_id')
            if user_id and user_id in user_data_store:
                for memory in user_data_store[user_id]:
                    if isinstance(memory, dict) and memory.get('channel_media_id') == channel_media_id:
                        memory.update({
                            'status': 'deleted_by_admin',
                            'delete_reason': reason,
                            'deleted_by': {
                                'admin_id': data['admin_id'],
                                'admin_name': data['admin_name'],
                                'admin_username': admin_username,
                                'timestamp': datetime.now().isoformat()
                            }
                        })
                        break

                # ذخیره تغییرات در user_data_store
                try:
                    with open(os.path.join(DATA_DIR, "user_data.json"), 'w', encoding='utf-8') as f:
                        json.dump(user_data_store, f, ensure_ascii=False, indent=2)
                except Exception as e:
                    logger.error(f"Error saving user_data_store: {e}")

            # 3. حذف از ساختارهای داده
            channel_posts_store.pop(channel_media_id, None)
            rating_votes.pop(channel_media_id, None)

            # 4. اطلاع به کاربر
            try:
                await bot.send_message(
                    user_id,
                    f"⚠️ #آگهی_{memory_data.get('memory_number', '?')} شما با کد <code>{memory_data.get('tracking_code', '?')}</code> حذف شد.\n\n"
                    f"📝 دلیل حذف: {reason}\n\n"
                    "🍀 در صورت نیاز به توضیح بیشتر با پشتیبانی تماس بگیرید.",
                    parse_mode="HTML"
                )
            except Exception as e:
                logger.error(f"Error notifying user: {e}")

            # 5. ارسال گزارش به تمام ادمین‌ها
            report_message = (
                f"⚠️ گزارش حذف آگهی\n\n"
                f"🔢 کد آگهی: {memory_data.get('tracking_code', '?')}\n"
                f"👤 کاربر: {memory_data.get('name', 'ناشناس')}\n"
                f"🆔 آیدی: @{memory_data.get('username', 'نامشخص')} - {user_id}\n"
                f"📅 تاریخ ارسال: {memory_data.get('timestamp', 'نامشخص')}\n"
                f"🗑️ حذف شده توسط: @{admin_username}\n"
                f"📝 دلیل حذف: {reason}\n\n"
            )

            # ارسال گزارش به ادمین‌ها
            for admin_id in admins:
                try:
                    await bot.send_message(admin_id, report_message)
                except Exception as e:
                    logger.error(f"Error sending report to admin {admin_id}: {e}")

            # 6. تأیید نهایی به ادمین
            await message.answer(
                f"✅ آگهی با موفقیت حذف شد و گزارش به ادمین‌ها ارسال گردید.\n"
                f"📝 دلیل ثبت شده: {reason}",
                reply_markup=await get_content_management_keyboard()
            )

            # 7. ذخیره تمام تغییرات
            save_all_data()






            
            user_id = memory_data['user_id']
            
            # بارگذاری آگهی‌های کاربر
            user_memories = load_user_memories()
            user_memory_list = user_memories.get(str(user_id), [])
            
            # یافتن و به‌روزرسانی وضعیت آگهی
            for memory in user_memory_list:
                if memory.get('message_id') == memory_data['message_id']:
                    memory['status'] = 'deleted_by_admin'
                    break
            else:
                # اگر آگهی در لیست کاربر پیدا نشد، آن را اضافه کنید
                user_memory_list.append({
                    'memory_number': memory_data.get('memory_number'),
                    'link': f"https://t.me/{CHANNEL_IDM}/{memory_data['message_id']}",
                    'timestamp': memory_data['timestamp'],
                    'tracking_code': memory_data.get('tracking_code'),
                    'message_id': memory_data['message_id'],
                    'media_type': memory_data['media_type'],
                    'description': memory_data.get('description', ''),
                    'status': 'deleted_by_admin'
                })
            
            user_memories[str(user_id)] = user_memory_list
            save_user_memories(user_memories)















        except Exception as e:
            logger.error(f"Error in process_deletion_reason: {e}")
            await message.answer("⚠️ خطا در پردازش دلیل حذف!")
        finally:
            await state.clear()


    @dp.message(F.text == "📊 اطلاعات ربات", F.from_user.id.in_(admins))
    async def show_stats_menu(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """نمایش منوی آمار"""
        await message.answer(
            "منوی اطلاعات ربات:",
            reply_markup=await get_stats_keyboard()
        )

    @dp.message(F.text == "📈 آمار اولیه", F.from_user.id.in_(admins))
    async def show_basic_stats(message: types.Message):
        await delete_message_safely(message)
        """نمایش آمار اولیه (معادل دستور /stats)"""
        if message.from_user.id != ADMIN_IDM:
            await message.answer("⛔ فقط سازنده می‌تواند از این بخش استفاده کند!", reply_markup=await get_admin_keyboard())
            return
        
        
        msg = await message.answer("📊 در حال محاسبه آمار... لطفاً منتظر بمانید.")
        
        stats = await generate_bot_statistics()
        
        try:
            # ایجاد متن گزارش
            report = f"📈 آمار جامع ربات - {datetime.now().strftime('%Y/%m/%d %H:%M')}\n\n"
            
            report += "👥 کاربران:\n"
            report += f"• کل کاربران: {stats['users']['total']}\n"
            report += f"• کاربران فعال: {stats['users']['active']}\n"
            report += f"• کاربران بلاک شده: {stats['users']['blocked']}\n\n"
            
            report += "📤 ارسال‌ها:\n"
            report += f"• کل ارسال‌ها: {stats['submissions']['total']}\n"
            report += f"• تأیید شده: {stats['submissions']['approved']}\n"
            report += f"• رد شده: {stats['submissions']['rejected']}\n"
            report += f"• در انتظار بررسی: {stats['submissions']['pending']}\n\n"
            
            report += "⭐ امتیازها:\n"
            report += f"• کل رأی‌ها: {stats['ratings']['total_votes']}\n"
            report += f"• میانگین امتیاز: {stats['ratings']['average_rating']}/5\n"
            report += f"• آگهی‌های دارای امتیاز: {stats['ratings']['rated_memories']}\n\n"
            
            report += "👑 5 کاربر برتر:\n"
            for i, user in enumerate(stats['top_users'], 1):
                report += f"{i}. کاربر {user['user_id']} (@{user['username']}) - امتیاز: {user['score']:.1f}\n"
            report += "\n"
            
            report += "🏆 5 آگهی برتر:\n"
            for i, memory in enumerate(stats['top_memories'], 1):
                report += f"{i}. آگهی #{memory['memory_number']} - امتیاز: {memory['average_rating']:.1f} ({memory['vote_count']} رأی)\n"
            report += "\n"
            
            report += "🖥️ اطلاعات سیستم:\n"
            report += f"• آخرین پشتیبان‌گیری: {stats['system']['last_backup']}\n"
            report += f"• تعداد فایل‌های داده: {len(stats['system']['data_files'])}\n"
            await asyncio.sleep(1)
            await msg.delete()
            # اگر گزارش خیلی طولانی شد، آن را به چند پیام تقسیم می‌کنیم
            if len(report) > 4000:
                parts = [report[i:i+4000] for i in range(0, len(report), 4000)]
                for part in parts:
                    await message.answer(part)
                    await asyncio.sleep(1)
            else:
                await message.answer(report)
            
        except Exception as e:
            logger.error(f"Error showing statistics: {e}")
            await message.answer(f"⚠️ خطا در نمایش آمار: {e}")

    @dp.message(F.text == "📤 خروجی داده‌ها", F.from_user.id.in_(admins))
    async def export_data(message: types.Message):
        await delete_message_safely(message)
        """خروجی داده‌ها (معادل دستور /export_users)"""
        if message.from_user.id != ADMIN_IDM:
            await message.answer("⛔ فقط سازنده می‌تواند از این بخش استفاده کند!", reply_markup=await get_admin_keyboard())
            return
        
        msg = await message.answer("📊 در حال تهیه گزارش کاربران... لطفاً منتظر بمانید.")
        
        try:
            filename = await export_users_to_excel()
            
            if filename:
                # استفاده از InputFile برای ارسال فایل
                document = FSInputFile(filename)
                await message.answer_document(
                    document,
                    caption=f"📊 گزارش کامل کاربران - {datetime.now().strftime('%Y/%m/%d %H:%M')}"
                )
                await msg.delete()
                
                # حذف فایل موقت پس از ارسال
                try:
                    os.remove(filename)
                except Exception as e:
                    logger.error(f"Error deleting temp file: {e}")
            else:
                await message.answer("⚠️ خطا در ایجاد فایل اکسل!")
        except Exception as e:
            logger.error(f"Error in export_users_command: {e}")
            await message.answer(f"⚠️ خطا در ایجاد گزارش: {e}")

    
    async def safe_restart(bot: Bot):
        """تابع ایمن برای خاموش کردن ربات"""
        try:
            # 1. ذخیره تمام داده‌ها
            save_all_data()
            
            # 2. متوقف کردن scheduler
            if scheduler.running:
                scheduler.shutdown(wait=False)
            
            # 3. بستن اتصال ربات
            await bot.session.close()
            
            # 4. خروج از برنامه
            sys.exit(0)
            
        except Exception as e:
            logger.error(f"خطا در خاموش کردن ربات: {e}")
            raise
        
    @dp.message(F.text == "🔄 ریستارت ربات", F.from_user.id.in_(admins))
    async def request_restart(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """نمایش کیبورد تأیید ریستارت"""
        if message.from_user.id != ADMIN_IDM:
            await message.answer("⛔ فقط سازنده می‌تواند ربات را ریستارت کند!", reply_markup=await get_admin_keyboard())
            return

        keyboard = ReplyKeyboardMarkup(
            keyboard=[
                [KeyboardButton(text="✅ بله، ریستارت کن")],
                [KeyboardButton(text="❌ خیر، انصراف")],
            ],
            resize_keyboard=True
        )
        
        await state.set_state(AdminStates.CONFIRM_RESTART)
        await message.answer(
            "⚠️ آیا مطمئن هستید که می‌خواهید ربات را ریستارت کنید؟\n"
            "✅ تمام داده‌ها ذخیره خواهند شد.",
            reply_markup=keyboard
        )

    @dp.message(F.text == "✅ بله، ریستارت کن", AdminStates.CONFIRM_RESTART)
    async def confirm_restart(message: types.Message, state: FSMContext, bot: Bot):
        await delete_message_safely(message)
        """تأیید و اجرای ریستارت"""
        try:
            msg = await message.answer(
                "🔄 در حال ریستارت ربات...",
                reply_markup=await get_admin_keyboard()
            )
            
            # تأخیر برای اطمینان از ارسال پیام
            await asyncio.sleep(1)
            
            # اجرای ریستارت ایمن
            await safe_restart(bot)
            
        except Exception as e:
            logger.error(f"خطا در ریستارت: {e}")
            await message.answer(f"⚠️ خطا در ریستارت: {str(e)}")
        finally:
            await state.clear()

    @dp.message(F.text == "❌ خیر، انصراف", AdminStates.CONFIRM_RESTART)
    async def cancel_restart(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """لغو عملیات ریستارت"""
        await state.clear()
        await message.answer(
            "✅ عملیات ریستارت لغو شد.",
            reply_markup=await get_admin_keyboard()  # بازگشت به کیبورد اصلی
        )

    dp.message.register(request_restart, F.text == "🔄 ریستارت ربات", F.from_user.id.in_(admins))
    dp.message.register(confirm_restart, F.text == "✅ بله، ریستارت کن", AdminStates.CONFIRM_RESTART)
    dp.message.register(cancel_restart, F.text == "❌ خیر، انصراف", AdminStates.CONFIRM_RESTART)


    @dp.message(F.text.in_(["🔽🔽🔽 پنل مخصوص ادمین 🔽🔽🔽", "🔽🔽🔽 پنل مخصوص سازنده 🔽🔽🔽"]), F.from_user.id.in_(admins))
    async def delete_creator_panel_message(message: types.Message):
        await delete_message_safely(message)


    @dp.message(AdminStates.WAITING_FOR_BLOCK_REASON, F.from_user.id.in_(admins))
    async def handle_block_reason(message: types.Message, state: FSMContext):
        await process_block_reason(
            message, 
            state, 
            bot, 
            admins, 
            blocked_users, 
            DATA_DIR,
            ADMIN_IDM
        )

    @dp.message(AdminStates.WAITING_FOR_UNBLOCK_REASON, F.from_user.id.in_(admins))
    async def handle_unblock_reason(message: types.Message, state: FSMContext):
        await process_unblock_reason(
            message, 
            state, 
            bot, 
            admins, 
            blocked_users, 
            DATA_DIR,
            ADMIN_IDM
        )

    @dp.message(AdminStates.WAITING_FOR_TEMP_UNBLOCK_INPUT, F.from_user.id.in_(admins))
    async def handle_temp_unblock_input(message: types.Message, state: FSMContext):
        await process_temp_unblock_input(
            message, 
            state, 
            bot, 
            admins, 
            user_blocks, 
            DATA_DIR
        )

    @dp.message(AdminStates.WAITING_FOR_TEMP_UNBLOCK_REASON, F.from_user.id.in_(admins))
    async def handle_temp_unblock_reason(message: types.Message, state: FSMContext):
        await process_temp_unblock_reason(
            message, 
            state, 
            bot, 
            admins, 
            user_blocks, 
            DATA_DIR,
            ADMIN_IDM
        )


    @dp.message(F.text == "📩 پیام به کاربران", F.from_user.id.in_(admins), UserManagementStates.MAIN_MENU)
    async def handle_send_message(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """شروع فرآیند ارسال پیام به کاربران"""
        await state.set_state(UserManagementStates.SELECT_RECIPIENTS)
        await message.answer(
            "لطفاً یکی از گزینه‌های زیر را انتخاب کنید:",
            reply_markup=ReplyKeyboardMarkup(
                keyboard=[
                    [KeyboardButton(text="📨 ارسال به همه کاربران"), KeyboardButton(text="📬 ارسال به کاربران خاص")],
                    [KeyboardButton(text="🔙 بازگشت به منوی اصلی")]
                ],
                resize_keyboard=True
            )
        )

    @dp.message(F.text == "📨 ارسال به همه کاربران", F.from_user.id.in_(admins), UserManagementStates.SELECT_RECIPIENTS)
    async def handle_send_to_all(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """ارسال پیام به همه کاربران"""
        await state.update_data(recipient_type="all")
        await state.set_state(UserManagementStates.CONFIRM_MESSAGE)
        await message.answer(
            "در حال ارسال پیام به همه کاربران. لطفاً پیام خود را وارد کنید:",
            reply_markup=ReplyKeyboardMarkup(
                keyboard=[
                    [KeyboardButton(text="🔙 بازگشت به منوی اصلی")]
                ],
                resize_keyboard=True
            )
        )

    @dp.message(F.text == "📬 ارسال به کاربران خاص", F.from_user.id.in_(admins), UserManagementStates.SELECT_RECIPIENTS)
    async def handle_send_to_specific(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """ارسال پیام به کاربران خاص"""
        await state.update_data(recipient_type="specific")
        await state.set_state(UserManagementStates.ENTER_USER_IDS)
        await message.answer(
            "لطفاً آیدی عددی کاربران را با کاما (,) از هم جدا کنید:\n"
            "مثال: 123456789,987654321",
            reply_markup=ReplyKeyboardMarkup(
                keyboard=[
                    [KeyboardButton(text="🔙 بازگشت به منوی اصلی")]
                ],
                resize_keyboard=True
            )
        )


    @dp.message(UserManagementStates.ENTER_USER_IDS, F.from_user.id.in_(admins))
    async def handle_user_ids_input(message: types.Message, state: FSMContext):
        """پردازش آیدی‌های کاربران"""
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.clear()
            await message.answer(
                "منوی مدیریت کاربران:",
                reply_markup=await get_user_management_keyboard()
            )
            return

        try:
            user_ids = [int(uid.strip()) for uid in message.text.split(",") if uid.strip()]
            if not user_ids:
                await message.answer("❌ لطفاً حداقل یک آیدی معتبر وارد کنید.")
                return
            
            await state.update_data(user_ids=user_ids)
            await state.set_state(UserManagementStates.CONFIRM_MESSAGE)
            await message.answer(
                "لطفاً پیام خود را وارد کنید:",
                reply_markup=ReplyKeyboardMarkup(
                    keyboard=[
                        [KeyboardButton(text="🔙 بازگشت به منوی اصلی")]
                    ],
                    resize_keyboard=True
                )
            )
        except ValueError:
            await message.answer("❌ لطفاً فقط اعداد را با کاما از هم جدا کنید.")

    @dp.message(UserManagementStates.CONFIRM_MESSAGE, F.from_user.id.in_(admins))
    async def handle_confirm_message(message: types.Message, state: FSMContext):
        """تایید و ارسال پیام"""
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.clear()
            await message.answer(
                "منوی مدیریت کاربران:",
                reply_markup=await get_user_management_keyboard()
            )
            return

        data = await state.get_data()
        recipient_type = data.get("recipient_type")
        user_ids = data.get("user_ids", [])
        message_text = message.text

        # اگر ارسال به سازنده باشد، مستقیماً ارسال کن
        if recipient_type == "creator":
            try:
                # اطلاعات ادمین ارسال کننده
                admin_info = (
                    f"👤 ارسال کننده:\n"
                    f"📌 نام: {message.from_user.full_name}\n"
                    f"🆔 آیدی: {message.from_user.id}\n"
                    f"🔗 یوزرنیم: @{message.from_user.username or 'ندارد'}\n\n"
                )
                
                # متن پیام با هدر پشتیبانی و اطلاعات ادمین
                support_message = f"📩 پیام از پشتیبانی:\n\n{admin_info}{message_text}"
                
                # ارسال پیام به سازنده
                await bot.send_message(chat_id=ADMIN_IDM, text=support_message)
                
                # اطلاع به ادمین
                await message.answer(
                    f"✅ پیام شما با موفقیت به سازنده ارسال شد:\n"
                    f"📝 پیام: {message_text}"
                )
            except Exception as e:
                await message.answer(f"خطا در ارسال پیام: {str(e)}")
            
            await state.clear()
            await state.set_state(UserManagementStates.MAIN_MENU)
            await message.answer(
                "منوی مدیریت کاربران:",
                reply_markup=await get_user_management_keyboard()
            )
            return

        # برای سایر حالت‌ها، پیام را برای تایید به سازنده ارسال کن
        pending_messages[message.from_user.id] = {
            "message_text": message_text,
            "recipient_type": recipient_type,
            "user_ids": user_ids
        }

        # ایجاد دکمه‌های تایید/رد
        confirm_keyboard = InlineKeyboardMarkup(
            inline_keyboard=[
                [
                    InlineKeyboardButton(text="✅ تایید", callback_data=f"confirm_message_{message.from_user.id}"),
                    InlineKeyboardButton(text="❌ رد", callback_data="cancel_message")
                ]
            ]
        )

        # ارسال پیام به سازنده برای تایید
        try:
            if recipient_type == "all":
                recipient_info = "همه کاربران"
            else:
                # جمع‌آوری اطلاعات کاربران
                recipient_info = "کاربران خاص:\n"
                for user_id in user_ids:
                    try:
                        user = await bot.get_chat(user_id)
                        username = f"@{user.username}" if user.username else "بدون یوزرنیم"
                        recipient_info += f"🆔 {user_id} | 👤 {username}\n"
                    except Exception:
                        recipient_info += f"🆔 {user_id} | ⚠️ اطلاعات کاربر در دسترس نیست\n"

            await bot.send_message(
                ADMIN_IDM,
                f"📩 درخواست ارسال پیام از ادمین {message.from_user.full_name} (@{message.from_user.username or 'ندارد'})\n\n"
                f"📝 پیام:\n{message_text}\n\n"
                f"🎯 مخاطبان:\n{recipient_info}",
                reply_markup=confirm_keyboard
            )
            await message.answer("پیام شما برای تایید به سازنده ارسال شد. پس از تایید، برای مخاطبان ارسال خواهد شد.")
        except Exception as e:
            await message.answer(f"خطا در ارسال پیام برای تایید: {str(e)}")
        
        await state.clear()
        await state.set_state(UserManagementStates.MAIN_MENU)
        await message.answer(
            "منوی مدیریت کاربران:",
            reply_markup=await get_user_management_keyboard()
        )

    @dp.callback_query(lambda c: c.data.startswith('confirm_message_'), F.from_user.id == ADMIN_IDM)
    async def handle_admin_confirm_message(callback: types.CallbackQuery, bot: Bot):
        """پردازش تایید پیام توسط سازنده"""
        try:
            admin_id = int(callback.data.split('_')[-1])
            
            # دریافت اطلاعات از متغیر موقت
            message_data = pending_messages.get(admin_id)
            if not message_data:
                await callback.message.edit_text("❌ پیام مورد نظر یافت نشد!")
                await callback.answer()
                return
                
            message_text = message_data["message_text"]
            recipient_type = message_data["recipient_type"]
            user_ids = message_data["user_ids"]
            
            # اضافه کردن هدر "پیامی از پشتیبانی" به پیام
            admin_header = "🔹 پیامی از پشتیبانی:\n\n"
            formatted_message = admin_header + message_text

            success_count = 0
            fail_count = 0
            
            try:
                if recipient_type == "admins":
                    # دریافت اطلاعات ادمین ارسال کننده (یک بار قبل از حلقه)
                    try:
                        sender = await bot.get_chat(admin_id)  # admin_id همان ارسال کننده است
                        admin_info = (
                            f"👤 ارسال کننده:\n"
                            f"📌 نام: {sender.full_name}\n"
                            f"🆔 آیدی: {sender.id}\n"
                            f"🔗 یوزرنیم: @{sender.username or 'ندارد'}\n\n"
                        )
                    except Exception as e:
                        logger.error(f"Error getting sender info: {e}")
                        admin_info = "👤 ارسال کننده: اطلاعات نامشخص\n\n"

                    # ارسال پیام به همه ادمین‌ها
                    for receiver_id in admins:
                        if receiver_id != ADMIN_IDM:  # به خود سازنده ارسال نکن
                            try:
                                # متن پیام با هدر و اطلاعات ادمین
                                admin_message = f"📩 پیام از ادمین:\n\n{admin_info}{message_text}"
                                
                                await bot.send_message(chat_id=receiver_id, text=admin_message)
                                success_count += 1
                            except Exception as e:
                                logger.error(f"Error sending to admin {receiver_id}: {e}")
                                fail_count += 1
                else:
                    # ارسال پیام به کاربران
                    if recipient_type == "all":
                        # ارسال به همه کاربران
                        for user_id in user_data_store:
                            try:
                                await bot.send_message(chat_id=user_id, text=formatted_message)
                                success_count += 1
                            except Exception:
                                fail_count += 1
                    else:
                        # ارسال به کاربران خاص
                        for user_id in user_ids:
                            try:
                                await bot.send_message(chat_id=user_id, text=formatted_message)
                                success_count += 1
                            except Exception:
                                fail_count += 1
                
                # اطلاع به سازنده
                await callback.message.edit_text(
                    f"{callback.message.text}\n\n✅ پیام با موفقیت ارسال شد!\n"
                    f"✅ تعداد موفق: {success_count}\n"
                    f"❌ تعداد ناموفق: {fail_count}"
                )
                
                # اطلاع به ادمین ارسال کننده
                try:
                    await bot.send_message(
                        admin_id,
                        f"✅ پیام شما تایید و ارسال شد!\n"
                        f"✅ تعداد موفق: {success_count}\n"
                        f"❌ تعداد ناموفق: {fail_count}"
                    )
                except Exception:
                    pass
                
            except Exception as e:
                await callback.message.edit_text(
                    f"{callback.message.text}\n\n❌ خطا در ارسال پیام: {str(e)}"
                )
            
            # پاک کردن پیام از لیست انتظار
            if admin_id in pending_messages:
                del pending_messages[admin_id]
            
            await callback.answer()
            
        except Exception as e:
            print(f"Error in handle_admin_confirm_message: {str(e)}")  # برای دیباگ
            await callback.message.edit_text(f"خطا در ارسال پیام: {str(e)}")
            await callback.answer()

    @dp.callback_query(lambda c: c.data == "cancel_message", F.from_user.id == ADMIN_IDM)
    async def handle_admin_cancel_message(callback: types.CallbackQuery):
        """پردازش رد پیام توسط سازنده"""
        await callback.message.edit_text("❌ ارسال پیام رد شد.")
        await callback.answer()

    # متغیر موقت برای ذخیره پیام‌های ادمین‌ها
    admin_messages = {}

    @dp.message(F.text == "👥 پیام به ادمین‌ها", F.from_user.id.in_(admins), UserManagementStates.MAIN_MENU)
    async def handle_send_to_admins_from_menu(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """شروع فرآیند ارسال پیام به ادمین‌ها"""
        await state.set_state(UserManagementStates.CONFIRM_MESSAGE)
        await state.update_data(recipient_type="admins")
        await message.answer(
            "لطفاً پیام خود را برای ادمین‌ها وارد کنید:",
            reply_markup=await get_cancel_keyboard()
        )

    @dp.message(UserManagementStates.CONFIRM_MESSAGE, F.from_user.id.in_(admins))
    async def handle_confirm_message(message: types.Message, state: FSMContext):
        """تایید و ارسال پیام"""
        if message.text == "🔙 بازگشت به منوی اصلی":
            await state.clear()
            await message.answer(
                "منوی مدیریت کاربران:",
                reply_markup=await get_user_management_keyboard()
            )
            return

        data = await state.get_data()
        recipient_type = data.get("recipient_type")
        user_ids = data.get("user_ids", [])
        message_text = message.text

        # اگر ارسال به سازنده باشد، مستقیماً ارسال کن
        if recipient_type == "creator":
            try:
                # اطلاعات ادمین ارسال کننده
                admin_info = (
                    f"👤 ارسال کننده:\n"
                    f"📌 نام: {message.from_user.full_name}\n"
                    f"🆔 آیدی: {message.from_user.id}\n"
                    f"🔗 یوزرنیم: @{message.from_user.username or 'ندارد'}\n\n"
                )
                
                # متن پیام با هدر پشتیبانی و اطلاعات ادمین
                support_message = f"📩 پیام از پشتیبانی:\n\n{admin_info}{message_text}"
                
                # ارسال پیام به سازنده
                await bot.send_message(chat_id=ADMIN_IDM, text=support_message)
                
                # اطلاع به ادمین
                await message.answer(
                    f"✅ پیام شما با موفقیت به سازنده ارسال شد:\n"
                    f"📝 پیام: {message_text}"
                )
            except Exception as e:
                await message.answer(f"خطا در ارسال پیام: {str(e)}")
            
            await state.clear()
            await state.set_state(UserManagementStates.MAIN_MENU)
            await message.answer(
                "منوی مدیریت کاربران:",
                reply_markup=await get_user_management_keyboard()
            )
            return

        # اگر ارسال به ادمین‌ها باشد، برای تایید به سازنده ارسال کن
        if recipient_type == "admins":
            pending_messages[message.from_user.id] = {
                "message_text": message_text,
                "recipient_type": "admins",
                "user_ids": []  # در این حالت نیازی به user_ids نیست
            }

            # ایجاد دکمه‌های تایید/رد
            confirm_keyboard = InlineKeyboardMarkup(
                inline_keyboard=[
                    [
                        InlineKeyboardButton(text="✅ تایید", callback_data=f"confirm_message_{message.from_user.id}"),
                        InlineKeyboardButton(text="❌ رد", callback_data="cancel_message")
                    ]
                ]
            )

            # ارسال پیام به سازنده برای تایید
            try:
                await bot.send_message(
                    ADMIN_IDM,
                    f"📩 درخواست ارسال پیام به ادمین‌ها از {message.from_user.full_name} (@{message.from_user.username or 'ندارد'})\n\n"
                    f"📝 پیام:\n{message_text}",
                    reply_markup=confirm_keyboard
                )
                await message.answer("پیام شما برای تایید به سازنده ارسال شد. پس از تایید، برای همه ادمین‌ها ارسال خواهد شد.")
            except Exception as e:
                await message.answer(f"خطا در ارسال پیام برای تایید: {str(e)}")
            
            await state.clear()
            await state.set_state(UserManagementStates.MAIN_MENU)
            await message.answer(
                "منوی مدیریت کاربران:",
                reply_markup=await get_user_management_keyboard()
            )
            return

        # برای سایر حالت‌ها، پیام را برای تایید به سازنده ارسال کن
        pending_messages[message.from_user.id] = {
            "message_text": message_text,
            "recipient_type": recipient_type,
            "user_ids": user_ids
        }

        # ایجاد دکمه‌های تایید/رد
        confirm_keyboard = InlineKeyboardMarkup(
            inline_keyboard=[
                [
                    InlineKeyboardButton(text="✅ تایید", callback_data=f"confirm_message_{message.from_user.id}"),
                    InlineKeyboardButton(text="❌ رد", callback_data="cancel_message")
                ]
            ]
        )

        # ارسال پیام به سازنده برای تایید
        try:
            if recipient_type == "all":
                recipient_info = "همه کاربران"
            else:
                # جمع‌آوری اطلاعات کاربران
                recipient_info = "کاربران خاص:\n"
                for user_id in user_ids:
                    try:
                        user = await bot.get_chat(user_id)
                        username = f"@{user.username}" if user.username else "بدون یوزرنیم"
                        recipient_info += f"🆔 {user_id} | 👤 {username}\n"
                    except Exception:
                        recipient_info += f"🆔 {user_id} | ⚠️ اطلاعات کاربر در دسترس نیست\n"

            await bot.send_message(
                ADMIN_IDM,
                f"📩 درخواست ارسال پیام از ادمین {message.from_user.full_name} (@{message.from_user.username or 'ندارد'})\n\n"
                f"📝 پیام:\n{message_text}\n\n"
                f"🎯 مخاطبان:\n{recipient_info}",
                reply_markup=confirm_keyboard
            )
            await message.answer("پیام شما برای تایید به سازنده ارسال شد. پس از تایید، برای مخاطبان ارسال خواهد شد.")
        except Exception as e:
            await message.answer(f"خطا در ارسال پیام برای تایید: {str(e)}")
        
        await state.clear()
        await state.set_state(UserManagementStates.MAIN_MENU)
        await message.answer(
            "منوی مدیریت کاربران:",
            reply_markup=await get_user_management_keyboard()
        )

    @dp.callback_query(lambda c: c.data.startswith('confirm_message_'), F.from_user.id == ADMIN_IDM)
    async def handle_admin_confirm_message(callback: types.CallbackQuery, bot: Bot):
        """تایید پیام توسط سازنده"""
        admin_id = int(callback.data.split('_')[2])
        message_data = pending_messages.get(admin_id)
        
        if not message_data:
            await callback.answer("این پیام دیگر معتبر نیست!")
            return
        
        message_text = message_data["message_text"]
        recipient_type = message_data["recipient_type"]
        user_ids = message_data["user_ids"]
        
        success_count = 0
        fail_count = 0
        
        try:
            if recipient_type == "admins":
                # ارسال پیام به همه ادمین‌ها
                for admin_id in admins:
                    if admin_id != ADMIN_IDM:  # به خود سازنده ارسال نکن
                        try:
                            # اطلاعات ادمین ارسال کننده
                            sender = await bot.get_chat(admin_id)
                            admin_info = (
                                f"👤 ارسال کننده:\n"
                                f"📌 نام: {sender.full_name}\n"
                                f"🆔 آیدی: {sender.id}\n"
                                f"🔗 یوزرنیم: @{sender.username or 'ندارد'}\n\n"
                            )
                            
                            # متن پیام با هدر و اطلاعات ادمین
                            admin_message = f"📩 پیام از ادمین:\n\n{admin_info}{message_text}"
                            
                            await bot.send_message(chat_id=admin_id, text=admin_message)
                            success_count += 1
                        except Exception:
                            fail_count += 1
            else:
                # ارسال پیام به کاربران
                if recipient_type == "all":
                    # ارسال به همه کاربران
                    for user_id in user_data_store:
                        try:
                            await bot.send_message(chat_id=user_id, text=message_text)
                            success_count += 1
                        except Exception:
                            fail_count += 1
                else:
                    # ارسال به کاربران خاص
                    for user_id in user_ids:
                        try:
                            await bot.send_message(chat_id=user_id, text=message_text)
                            success_count += 1
                        except Exception:
                            fail_count += 1
            
            # اطلاع به سازنده
            await callback.message.edit_text(
                f"{callback.message.text}\n\n✅ پیام با موفقیت ارسال شد!\n"
                f"✅ تعداد موفق: {success_count}\n"
                f"❌ تعداد ناموفق: {fail_count}"
            )
            
            # اطلاع به ادمین ارسال کننده
            try:
                await bot.send_message(
                    admin_id,
                    f"✅ پیام شما تایید و ارسال شد!\n"
                    f"✅ تعداد موفق: {success_count}\n"
                    f"❌ تعداد ناموفق: {fail_count}"
                )
            except Exception:
                pass
            
        except Exception as e:
            await callback.message.edit_text(
                f"{callback.message.text}\n\n❌ خطا در ارسال پیام: {str(e)}"
            )
        
        # پاک کردن پیام از لیست انتظار
        if admin_id in pending_messages:
            del pending_messages[admin_id]
        
        await callback.answer()

    async def get_officials_menu_keyboard():
        """ایجاد کیبورد زیرمنوی پیام به مقام داران"""
        keyboard = ReplyKeyboardMarkup(
            keyboard=[
                [
                    KeyboardButton(text="👥 پیام به ادمین‌ها"),
                    KeyboardButton(text="👑 پیام به سازنده")
                ],
                [
                    KeyboardButton(text="🔙 بازگشت به منوی اصلی")
                ]
            ],
            resize_keyboard=True
        )
        return keyboard

    @dp.message(F.text == "👑 پیام به مقام داران", F.from_user.id.in_(admins), UserManagementStates.MAIN_MENU)
    async def handle_officials_menu(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """ورود به زیرمنوی پیام به مقام داران"""
        await state.set_state(UserManagementStates.OFFICIALS_MENU)
        await message.answer(
            "منوی پیام به مقام داران:",
            reply_markup=await get_officials_menu_keyboard()
        )

    @dp.message(F.text == "👥 پیام به ادمین‌ها", F.from_user.id.in_(admins), UserManagementStates.OFFICIALS_MENU)
    async def handle_send_to_admins_from_officials(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """شروع فرآیند ارسال پیام به ادمین‌ها از زیرمنوی پیام به مقام داران"""
        await state.set_state(UserManagementStates.CONFIRM_MESSAGE)
        await state.update_data(recipient_type="admins")
        await message.answer(
            "لطفاً پیام خود را برای ادمین‌ها وارد کنید:",
            reply_markup=await get_cancel_keyboard()
        )

    @dp.message(F.text == "👑 پیام به سازنده", F.from_user.id.in_(admins), UserManagementStates.OFFICIALS_MENU)
    async def handle_send_to_creator_from_officials(message: types.Message, state: FSMContext):
        await delete_message_safely(message)
        """شروع فرآیند ارسال پیام به سازنده از زیرمنوی پیام به مقام داران"""
        await state.set_state(UserManagementStates.CONFIRM_MESSAGE)
        await state.update_data(recipient_type="creator")
        await message.answer(
            "لطفاً پیام خود را برای سازنده وارد کنید:",
            reply_markup=await get_cancel_keyboard()
        )

    async def delete_message_safely(message: types.Message):
        try:
            await message.delete()
        except Exception as e:
            logger.error(f"Error deleting message: {e}")